
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']


def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    pass


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    pass


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01d\x02\x83\x04'
        b'\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xde*\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t0\xe0\x02\x00\x00\x00'
        b'\x00\x01\x00\x00\x00@\x00\x00\x00\x9e*\x00\x00\x00\x00\x00\x00#H\xf6\xcac"\xe5\x06\x1aX\xd2\x072\xa6\xcf[\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC\x15Z,F'
        b'\xdc\xcc~\xc2=\xf9\x7frX\xcf\xf7\x89o\xccp\xaf\x0e\xea\xc7\xd4,\xbd\xb4\xbcyF"\xac\xd7X\xc8\xd3EX\x8d\xe7\xba\xf5%H\x11)\xf1\xffI\xf5kZJr\xbcX\xc2\xb3,\xac0\x83\x9b>v\xccA\xd4'
        b'\xaa\xe9&b\x92\xf2\xb9c\xfc\xec\xbf\xdd\xe3b\x15\xbd\x84\xa0\xbaG\x06R\x1b|\x1e\x9d\x14L\x83\xb1\xaa\x03|\x1a\x13\xef\xa0\xf6\xb8\xbcSW\x85&\xa1\xb0\xbbU\x9bM\x07\x8d\x0c\xfcl\x15\x01\xaf\xb6T\xfa\x81B\xf8'
        b'\x8f\x0b6\xa9\xe7\xe9\x97\xde\xf00\x1f\xc0\xf3\x11\xcav\x04\xd1|F\x98\xefK\xeb7\tk\xb2\xb7\x132_\xb6e\x03\x1d\x00\x7f\xad2\x04\xf1\x06\x1c\x19\xc3!\x02\xba+\x7f;_\xe4p\x1aI\xc9\xe9\x15c`A\x93'
        b'S\x1c+\xc6J\x9d\x9c\x04\xf3\xa2\x87l\xe77OI\xf2\x85:\x93\xd7\xc5\x83\x898\x01\xd0\xdd%Mud`\xd4<a\xf5\t\x87\xd0\xab\x03\xa6\x8d\x9a\xbe\xce\xd5U\xb0l\xd8!\x0b\x94\xd9\x11\x17/3\xd1\xbe\xcdz'
        b',_\xe3\x990G\x10\xb0+\xbe\x80$T\xd33\x95\xf6%\xf2^\xa3\xe6S\x01\xc8~i\x94F\x82\xc1\xc4\x7fv \x81\x1c\xa2\x17z\xb2[\t\xbbP\t\xf9\xa6\xdb|\xae\xa0Y\xd0\xfd\xc7\xd1\xacZj\xf3[N\xd3'
        b'M9\xa3\x97\x8f\xd9>{\xf3j\xe6L\xa5\xad\x84e1\xcd\xcc\xa4\xb0G\xefRE\x93b\x7f\xd6\xf7\xd4df\x95\x04\x96\xb5\xc8\xca\xfbQ\n;\xbe\x01\x82\x9f\x9aC\xaa\xde{\xd9\xd2\xfd\xa7\xeb\xc6\xabH\xabe\xfc\xc5'
        b"\xb4_'kM\xe9\xbf\xbc\x07\x96gC\x89\xdca\x05\xe2\x04\xa9AZ\xfd\x12\xa1\xc4\x96\xfa\xc8.\xfe\x8b\xf6\xac\xfd\xdd\xab\xa7i\xa2\xdc\xd2h\\\xbeT\xa9J\xe4{/\xf5\xd4S1\xe6\x1f\x9b\xbc)\xa6\xc6\x1d`1"
        b'\x0fyO\xfc3\x1a\x1f\xcc\xc3F\t\x8d\xfe\x14\xbaC\xe1\xf1\xa2`\xd5&T\x92\xe5\xf3\x85J\xc9-\x1f\xf3\x89[\xab\xe6\x01m\xc18\xafL\x9b\x89f\xc2K\x80\x97\x18\xd8~\xe5\x08\x16Bp\x0cn\xe1W\xec\xc6\x8f'
        b'\xee\xc51\x9c)\xb5\x11.L\xa4c\xb2\xcen\xe2/9\xe8U\x16/\x96\xfe\x1cC[\x07\x8d\xe71\xdc.t`\xd2[4^\x18>\xd9\xdf\xf7\x1ae\x9c\x99\r\xfc\xa3\xc1\xe5\xd9`\x9c.\xc8\x07A\xe6c6\xc7X'
        b'rz\x16\xf1"\x06A\xce\x88c\xdfB2\xb3\xa6\x00&a\x11\xdb\xb3\x9d\x0f\x8c#\xb5\x14\x95\xce\xa14\x86\x9be>\xc2\xec\xa6m\x99\x84\xcf\xfc\xdd\xd8\xe5z\xb3\x9b\xc7jP\x9e\xdf\x9e\xd7\xa0\xd5b|\x871%\x9c'
        b'g]"Z\x18\xf6(\x04\x14\t:j\xf2\x0e\x13R\x86"k"\x9b$\xaf\xe8{"\xffJ\x82}\x01\x98\x8d\x9am\xfb_\x0f<\xed\xf8\xd2\x8b\xb3 \ng2\x9dB\xde\xe8\x03\xe7\x04O&\xa8\xe7S\xb3\x84,m'
        b'\xf7~c\xc0\x9dm\xdf\xf5\xe7\xb7\x83?R\x04\x84\xce\x10\xbd\xda\xad\xe2\x10\xa7\xf5\xd7q1Z"\xb5]\xfb\n\xf1\x80\xff\xad\xbfg\xf4\xc8d\xae?w\x0c\xdc\x1a\x8b\xc6\xd3\xb5\x91\xf9\x92YS}\xcc\xd2u\xea\x1e\x17'
        b"$\xbbN\xdb\xb4\xeb\x8c\xf8\x19\x17-Q\xd7\x8a3>\xf8\xfa\xc2\x14~\xf0\n\xb9\xae\x8f\x93\x1a\xd2\xacMM\xff\xfcq\xc0\xda\x01\xd6-\xe3Rh(\xd1\xd3\xef\xb1\x9fb\x81\xbc\xb7qS\xab\xc8\xf1\xf5\xe8\xb3'\x87\x14"
        b'R\xbez\x1eL\x95\xfc\xec\xb40(\x15\x12\xb5Vr\x82\xf0|\xb1\x93mm,D\xb1\x0f#\xc9\xcd\x86`V\xa8h[{\x9a\xea\xebo\x106\x8f\xb3\xc3\x1a\xdc\x86iM\xbf\xcaT[\xa5\xda\x1b&\x8e\x13\xa0\xa4\xb9'
        b'\x83\xc1\xae\t\xc8\xa3E\x8eMK\x8c\xde9R<U\xb3\xbf\xbb4\xb8K\x12\x16\xdc\xe5F\xc8\xdc\xa1\x0f\xa8\xb8\x13\xab^\x9f7\x90(\xf1\xe1\x06\x04r\x1e\x91\xe8OE\x97K\xedd\xfe\xd7/\xb1\x8f\x8e\xf4Vx\xd3'
        b'>\x0c,n\x12\xced\xf8\xc43\x14\xaa \xd0\xaf\x03oz\xe3@\x85\xd1=_\x18\xd7(y\xb3\xd3<\xe7h\xf5\xe2#W\xde\xfd\xda\r\x0c\xed\xf3\x94n\xe3_\xf5A^\xd9\x90\xac\xde\x9d\xe8k\xa3\x81)\xb0n\x03'
        b'\x1c\xc5\xce\xd0\xb9\x7fJ)S\x03\xb6\xdef6%jO\x11\xc71{\xe3\x94o3\xde\\\x98\xbc}\xfeS\x04\xf3\xdb\x12\x93\xdf\x8ce\xe3\x95Xbf$-w\xec\x1e\xeb\x12~S\x1a\xbb\xbd\x93\nU\x14\xd2\xe5['
        b'\xd4\x82$\x08\x86\x0b\xdf\xd6\x8aA\xec\xad}\x13@*\xa8\xc0\xcf\x17{%\xe9\xc1\xb2\xfa\xdd\x8c0\x7f9\x9e\xd7\xec\x8a\xa9\xc6\xdd~\x0b\x9d\x1a\t\xf1jA\xfb\xffae\xa8\xba\x13\nTs\x14\x03v\x05\x1e\x04\x8fj'
        b'\xc5\xa3\xd9\xb4G$@\xd5\xac\xc2\xdeZ\xb0\x85\x98\xad\x80\xb50_\xd5<b\xb5)]i\x96n\x7f\x9fcX\x07\xc3Q-\x87Z\x11\xac\x99\xfby\x87\x84F_\xca\x14W\x95m\xce\xcd\xfd\xe4\xebP+\x92\xea\x14\xa4'
        b"\x17]+\x933k\xa4N@\x01\x1c\xd0\x7f]9\xe30\x9e\x94e8CR*\xb5\xce\xc0\x85\xf0\x1b\x82\xd0\xfd\xf6\xd7D\x15e_\xe1\x90\x13\r\xce'\xc0[\xde\x9bM\xff\xac+\xf8\xa9\x05&\xf3\x8b\x14\x85e\xd5\xf2"
        b"r\x8f\x19@\xf4\xe2\xfb\x1fH\xe8 \xb7\xe1\xcf\xd3~oZuR\x167N\xd1'\xff\xb3\xef\x81T\xf1t\xfc\x8bM(\x83z^\xe9\xdb\x95z\xbd\x8c\x0f\xa8\xad\xf2E\xe8\t.\x82\x82\xb5Q\xceO/z\xd8>\t"
        b'\x82\x9e\xb6\xd2\xf4\xbe\xf1\x06rV\xab\x7f\xa8\x8bhe\xc3\x85\xad\x12:.l\xb1\xcf\xdaB"R\xe5\xbc\x1d\xb9\x7f1\x1e\x92\xba%\x89TW\x9f\x81\x9a\xc6\x0b\x85g\xcb\x06\x95\xa8\xef\xc4aJ`\xba\x9e\xd4\xa8b|'
        b'\x10\xdb*r\x935b\x11b\xf2\xc1\x97bs\xc1A2r\xa3\x8a\xf3\x90\x90\x14\x96#C4Is\xcaa\n\xc5>S#\xe2Bl\x12\x8a?Q\xef\x1a\xf5`pLl~_R/\x14\xdc$\xacG\xc4l\xc5Y'
        b'HM\xc6\x08AT\x80<\xb66.A \xd9=\x11\xb6?\x05\xcev6\xae\x16\xb5\x1d\x1f\x97\xf8\xc3\x15\x1bG$T\xc5\xb8\x86v\x93)J:\xb0\xcc\xad\xa3\x97\x11\x84Y\x9c(&^\xc0\x83\x84LU;\x13\xc3\x1a'
        b'\x17\x8b\x8f\x10c\r,\xe5\xc2{\x1c\xb6\xbde\r\x01z\xce\xcf\xd6\x83\xa1Z\xb2\xdbP\xd0\xd5\xc4\xd9\x8e\xc8n\xf9\xcd\xae*\xaf\x81\xc6Xo`>\xe8\x7f\x12^\xa0\x8f\xed\xa1\xcd\x8e\x97\xba\x1e.\x89\x10\xd3s\xc4\x1b'
        b't\xf7D\x1fT\xaf\x99\xa1\x1e[oB.U\x0f:}\x04X:\x17\xa1\x89\r%Nx\x98\xf1\x14\x84 \x9d\x0e~\x90\xcb`\x94\xde\xd2\xdal\xec\x15\xcc\xd2\x81\xfe<?\xd2x\x8es\x16k\xc5Na}a\xa9\x96'
        b'_!\x1f\xb4\xb8\xbf|\xfc\xaa\x0b~#\xfd\xd6X\xa3]pD/\xd4\x9d\xf0j+\x9e\xa4\xe50\xe2"0Mc\xacIYVb \xe2\x97\xbe\xe7\xb9+\xb9\x13\xe1\x05\xa8\xcb\xf7!J\xadg\xc5\x82\xc0\xd1>\xa4\xd0'
        b"\x97?\x17f\x1b\xf6\xf0<\xf1\xc1T\xbc\x1ao\xdd\x12\x11\x9e\xaa\x19\x8b\xd3\x7f\x00'\x8d\xcfy\xf4\x93P\xbe\x05\x19\xd0\xd7\xe9]\x10\xc4\xa6\xff\xbe]\xb2\xc6f\x02\x95\xef\x10[ \x85\xc1\r\xbe\xc8\x13\xf7\x9c0i\xc9"
        b'wS\x15\xae\x90\x86CpNF\x84\x0c<B\xf3\x8c\x05s\xc1\xc6)\x94\xe5\x83\xcdFD\xb9\x9c\x0b[_\xe0kdV\xbe\xaf44\x8d \xde\x89\x11\xdf6S\x14\xa2\x9e\xb5\xa0t\x9c\xe7i$Q\xb6\xcb1W\x0c'
        b'u!Q!\xf3\\\x1bz\xa6\xa2\xd6\x84m\x90\x9e\x14\xcb\x99z\xf0\xdc\xf3\xd6\xec\xc5\xebR>\xee\xf7Q\xf0\xbc\xf9\xc5\xf3\xb8\x9a\xa6\xdb$\xce\x9c\x02\xc3\x9e.\xc6\x92\t\x0b\x8c\xe9\x16=c\xdfRj#*\xdeq{'
        b'\x83f\xa7E\xc0\xf9%\x8ez\x191\xc1k\xf5\x8a\xa1\x87\xc1\xe9\xb3xJ>j/z\xac\xa3\x8b\xbd<y\xc5\xe0\xf2{\x7f\x1d\xf8\r\xec(\xff\x97_88Q\x01\x16\xb0e\x19\x0f\xc1\xd5ohX\xa0\x83\xbf\xe0\x81'
        b'\xf3\x9dmo\xdf\x0f\xde3S\x1bY6\xdcZ\xd5\n\xd8Z\xaf(\x06\xef-I\t\xbe\xe9=\xa2\xb0\x8f\xb7;\xc0\xad\x99\x1cI\x95\xd5\x9e\xb64\x1b\xf5\xc2\x87Z\xb5\x8cr\xd9\x15\x88\xcb0X9E{\x89O\x88\xd8'
        b'\xff&\x817m\xbe\xe1}\x9b\xee\x85\x8a\xac\xac\x01m\x85\xcd\x0c\xb6\x1d\x15+(\x06E\xd4b^\xa2\xaf\xd12\xce`\t\x81\xcf{p\x8076\xf9\xa3\x8b\x94&\xef\xab\xc2\xbb\xcd\xfd\xf1^A\x07"\x8d8|r\xd6'
        b',\xb8\x01a\xa9\x89\x9f\x957\x1c\xc8!f+#\xf9\x01\x05\x99&\x92\xdb\xdf\x11\x8afr\xdf\x88\x96\xa3\x98\xf7\xdc\x9a\x89\x12H\x8b\xaf\xc6\x9e1k\xf8\xf0L\xf6\x8fa\xcf\xe5\xcb\xfb\x92]e\x1d\xfaZ\x141F\xf6'
        b'\xc9\x8f\x83\xcb\x1c\xf8\xb2!\xedHN\x88\xea+`\t\xbcW\x8b\x98\x9a6\x19\xc0\x10L:q)\x18\xcf\xd5\\3\xcc\xe2\xd0\xf75\x19\xe9\xde\xe6\xe8\x95\xd9\xa5\xa2<-\xe4h\x10\xaa\xe3\x9a\xd0\xd8\xd5\x94\xc4\xcfMw'
        b'v\x1f\xee&p\x1f%l\xd8\x9fh\xe5\xd3:\x10\xc6\xf2\x99\xe1x>\xf2\xfa\xc4\xf5\xd3\x01m\x9c9\xf7\x13\xeb\x1b\x14\xc4\x84\xc7,\xcauG\x9b\xf1q\xf4s\x0e\x17\x8fm4\xea\xecMi\xb6\x04\x1b\xc9\xaa\xb1\xb4\xf1'
        b'\xef\xd9sS\x90^N\x95\xb3&\xb4\xbb\x91\x11K\xbb\xda\xccXZ\xbdW\xa3\x14\xae(\xef\x07\xae\x1d\x0f\x18x\xb1\xed\x9d<\x9f\x92\x13^\x05\xa5w\xf8\xb7,\x9a\x16\xfa&\x8c\xb2\xd8\xd6O\xc3\r,w\xedT\x86z'
        b'\xd22O\xb7\x19@\xbcr\xd8\x01\x82u\\J\x9e\x94\x154\x87!m\xc1.\x97"\xc7\x0f\xb2.<\x95\xf4\x9bZKc=\xe7\xcc\x83\x8c\xeb\x83\x90t\x98o\xc6c%i\x88\x981Z\xd5S\xfb\x00\x96\xe0\x90T\x7f'
        b'\x1e\x7f\xd8\x04i$&\xa4\xf0\xae\xb1\xa6\xa7\xee\r\xb1\xe8\xda\x0b\xdaW\xb3\xa6\xbc\xd0\x86]R*\xb8%0\x16\xc3\xc0\xe9`\xc3\x89}\xd9\xf3]\x01\xd0\xa4\xbdp\xfd\xa6#\x11\x0f\xe0\xfbaj/\x13Y\x00\x98 \xaf'
        b"\x0b.\x0e\x1c\xfcS\xd9J\x9bY\xd9\xfc\x82T`\x94\x91x\x84\x0b\xed\xc8\t\xea\x11\xae\x11\xfc\xf1y\x87\xd4G\x07\x15\xe2(\x13\xe5?\x92p\xad~4\xf8PRw\xa2\xa4\x06~\xce\xfc'\xc3\x14\xc3fh\xa8\xb3["
        b'\x13\x07\x92\x14O\x1f\r\x8c\x19\x9c\x89>\x97\xa5\xc8^O\x04\x96\xd4\xd8\x9a\xd0y\xcf,\xd5T\xdbs2\xe2\x1bx\x11l\xc1\x13<\xd9\xd0J\xbe\xfa\x1aU\xd6\x14U\x10w\\\x82\x07N\xf2\xe6\xac\xda\xe2\xa4\xc2\x15!'
        b'+\x0bT>\xf0\x80\xbaw?\xf5_\xd7~\xde\xaf(\xfc\xd7\xeeT;\x1aFv<\x1d\x16\xb0D\xcb\xe3\xf8\x1c\xae\x11\xf8\x9b\xa9\x83\x9e\x12\x82\x91\xc83\xc7\xca\x1d\xab1\xdb4\x9e\xea\xcc\xc9\xa1K\xafa\n\x99\xa7-'
        b'\xdf\x01\x0c\x02/\x1d(\x07\xca\xc4\x11"\xe9\x98D*Ur\xe8\xdb\xe2S\xdd\x1bt^\xb7<\x11X\xf8\xf3e\xc5%\x9d\xd1\x7f\xeb\xb4!p\xe4\xd0)&\xa7\x0f\xd2\x84\xb4\x93|)\x9e\x8d\xab\xb1n\x1a\t&\xa2\xe5'
        b"\xec\x96)\x084YcH9'\xb6rkV\xea\x8b\xe9\x86\xe7\xaevb\x8f\xd9\xac4\xe3\xb1\xa1-\xf4\xd9\x1b\x89u\xa1's\x94J\xf4N\x05D\x03j\xbdM\xaa\xe3]\xd7v\xe8\x98\x17\xbfSK\x90\x8b\x1e\x86\xef"
        b'G\x83x\x95\xd6\x1b\xc8\x187\xb2\xc8\x90Qz\xe8r\xbeG\xa7|AZ\t4\xee\xc7=|\xd7\xceE1J\xfd\xaaE\r\x17\x07J1\xefk\x82 \x9b@KF\xf2\xbaC\x90\xbe\xbf\x04K\xd6\xa5\xc3\xe8\x82S.'
        b"]B>\xa6:\rX'\x87\xeb*M*@)\xca\x9c\xe4\x14\x9fB\x0c{\xd1\xa4\x02\xe16g\xa4\x13\xe0\xcc\xe8\xbdLW$R\r\xfa\xfc\xc7\xc24\xf5X\x19HQ\xc9\x1a#\x7f\xb6\x0f\xfe\xce\xb8\xfe\x1c\xcb\xe2\xe6"
        b'\x98\xcb\n\xa5\xdd\xca\x1cq\x0b\xf6\xf3\xce\x81\n\xd8\x9f\xba\r"1\xed\x96z\x10\xd8k\xe5\xa6\xbe\x03\xf9\x0bL\xd2\xb1\xc5\xa0\xa3\xdf%\xcc]\xfd\x87\x0c8w.7E\xda\xad\xb0R\x08\xd3\xca\x13E\xc6\xae\xff\xef\xfa'
        b'\xd5\xea\x18\x12\xd8x\x82\xe7\xca#\xac\x86L5]\xd1\x828:ny\xc2\xbd.\xb0F\ry\x9d\xa0\x95\xa7\xaf\xdf\xa2\xa7cI\x0fV\xe2]\x80a|\xe2\xbei>n\xd4\xc4D\xc7k\xc2g\no\xb2}\xd70B'
        b'\xf4\x83\x8a"\x1c\xdd\xdaF\x06~w{\xf7C\x97\xa85\'dTb\xfd\x88\xc5\x17\x9a~\x87\x13<\x0f\xc8d\x96\x0c,\xac`\xf0\xb0\x16\xfe\x88u\xa4\xd9qM\x8c\xc0\xe3\x011Bet\x97\x06H\x03\xa6\xdcHs'
        b'ZV&\x18\xe1j\xe5\x82\xf6*N\xc8\x88 }\xf11..\xa7\xe48i\x8f;\xbe\xa7\xdb\xb7~k\xa5\xfeN\x8c\x87\x9b)u\xff\xaa\x9a\xa9\xd6\xbd\xaf\xc9\xa5\x810\xe1\xff#\xa1\x0f5r\xa5\x18\x8d\x11\x84\xacq'
        b'\xa9\x89\xa5\xac\x97\xc1\xa3\xdf:\x14{\xc2\xb8\x9bs\xa1\xe8\x82\xdd\xf4\xe3\x08\x91P\x1f\x08\x1cC\xffpP3?\xdc\xd9\xe2\xa5[\xa4z\x06 G6$o\xff\r\xa6\x8a\n_\x15\xe4n\nT\xdb\x83\xf8\x89\xc3t\x03'
        b'\x8aw\xec\x13X\xc5\x14\xa3\xce\x1c\xbf\xad\xe4J\x93\xb2\xda\xb6\xa2][a\xa5\xe7#\x97\xb6X\xf0,o\xde\x0f\x88W?\xe5\xf0"\x00\xc2\xc7\xa0\xbb\xfb7}\xae\x12\x16)\xfa\x98*\x1f\xd1\xafS\xea\x8d\x0f0L\x8f'
        b'\x8c\x9f\x82\xb4v\x98\xe4\xf0\x1b\x02\xce)\x7f\x97\xa7\xab\xb2\xd0\xdb\xc0Z\x17\xcc\xfe\xb0\x98\x0cgz\xeb\xf3o\xb7\xab\x85\xde\x8c7\\>_V\x85\xedA\x9dr\xeem+k@\xf3\xb2M\x8d\x19\n\x07K\xfc\xe86W'
        b'\x90\x08\xf7\xad\x80\x00\xbc:C/\xf1p8*k \xb4\x00\x92\x0b\x8a\xc8\xebi\xf4\x14\x95P\nn\xfa\x86\xa0\xc7nH\x0fm$|\x0c\xba\x82\x9c\xad}\xefT5\xb4g&\xc0\x83`Mv\xb7\x95z\xf92\xf2o'
        b"\x92>\xfc-*\xac*\x1e\t=\xd7\xf2\xd3\xd3'\xbb\xc0\x8e\x03\x16\xccsJ\xdc\xdfq\x03K\xec\xc9O\x88\xee\x06\xdb\x92\xfe\x08\rZ\xd9\x0f!\x93\xb4\x08ax\xa7\x01\x81\xfb8\x1c\x8a\xe7q\xfa?>\xe7J\x13\xa2"
        b'K\x14\x1e|\xcaO\xe8\xcfR\xa2\x8cI\x95\x1f y\xc9\xdb\x8b\xb8#\xadb\x9d\xb0\x10\x18\x88\xa6\xf3\x9aW\xf5`c\x11/\xbf\x99E7&\xb8\xb1"6\xb9\xb9\xb2o;\x1f\xedAP\x13\xd4,\xb7\x19\x98l\xe8\x84'
        b"\xa7dGZ'\xc0\xfd(\x1cu6(\xbd.#e\xcd\xab)\xe4\x7f\xa9\xc6v}\x94\x13\xb3\x06\xf3\x1f\xa9b\xa2\xa9Xs$\xc9\xf5\xa7\x00V\x96lqoX\x02\xb6\x98ZJ\xc5\xfcg\x86\n\x03\xd1\x9f&\x94W"
        b"\xe7\x17^\xcf\x17\x15\x8c\x95\xeaa\x8f\xa2}\xa3'\xc1'\xc7g\n\xc2S\xce)\xc9\xb5;\xd0z\xf4\x134\x8dN\x1c\xd1J7\x17)\x9e\xa6\x04\xf0\x8dz\xffU\xb7\xa8\xb9\x1e1\xfeq\xc07\xb3?\xe7\xfd\xaa \x1d"
        b"_\x11\xd4\xc2f\xcf\x91>\x06\xdf\x1c\xcaK\xea2\x03d\x13\xe46\x13wB\xa18;9*T\x95\x7f\xad\xab`\xb9\xaa\x0c\xad\xfc\x07\xafj\xd7\xbe'\xf7\xef\xfc\x9aO\xcc\x87\xf4\xf19zx\xe7\x1a\x8c40\xf5 "
        b'%N~C\xb8n\x83@\xc2\r\xda\x8b\x9e\xa2g\x06\xb6\xda`\x1an\xb6\xdf\x94\xce\xa1\xbbw\x89\x12\xe5\x19\xf8Y^\xd0~\xe6\xba@.\xdb\x01\xe8)\xe7\xd7n*Q\xae\xe1\x9b\xb3\x122\xacV\xd3\xb3\xb3\xfc\xf2\xc9'
        b"\xac\xc5\x19T\xa6^8\xb4\xf4\x80\xfe\xc2f'b\xc1\x8c\x00\xd8\xbb\xe5\x98\xe4\x1fv7s4\xb8\xef\xa7\xe4\xbf\xa3\xc7\xe2\xb7\xa5\xdb*\x1eZ&\xa4\x02\x05\xd3\xa7k\xd2\x0e\xb7ScWHY\xfcj\xf8\x89\xbb\x80\xdd"
        b'\xbc\x89\xc4\x1d\x9b\xe1\xe1|U"\x96Y\xc5IGi\xf6\xf3scU\xba\xacGqC+\xb7\xc8f\xdf\xc4\xe9\x07-<\'-\xbf\xea\xbd\xba\xac.\xb4\x06\x03a\xb3\xc8\xb7,d/\xb1z$\xbb\x11`\xfd\xfd_2'
        b'\xdf\x0bb\xcae\xe3 \xed\xad\xc7\x84\xbfq\xa9\xcc\x90\xbd\x99\x91\x05}\xf6\xdf\t\xeb\xea\x18\xe8\x87\xb7\xdf\x18\xd6UJ\xee\xb9\x8d\x98IE\x16\x886\x81\xfb\x08\xbb\xa0?\xfb\xf8g\x83\x7f)r\xcc\x99r\xcc&\xa1\xf9'
        b'\xe6\x06\xa3\x16\x06\xf0\x1c\x0cFs\x94\x12\x88\x1e\x02Ppu\t\xc5\x10\xb2[\x9fH`Q\xb8\x96\xf9\xab\xa1\xf8\x00$\xae\x88\xf3\x8a/E(f\xe1\xb4\xb7q\x18\x03\x00\xba=\x85 \xff\x14\xe5\xa8\xdc]F\x17\xfe\xe8'
        b'O6\xdf\x03\x16\xb41?$\xb1\xbb&\x81d\xdb\xf7\x06\xfa0\xa0;#\x19#\xe5\xca\xcbCa\xbe^)\r\x80\xee\xd0\xdd\xe2\xf2\xd3\xcb\xa8\xf5gf.\xf8\xac@\xd2W\x05\xf1"\x84\x17z\xbb\x18\x16,\x1b6\xff'
        b'\x1c\xd4Q\x89nu\x7f\rz\x1a\x83\x84\xb9\xb4\xfb\x06\x15\x18\xf8glR\xeaK3\x97\x13\x95\x80\xdc&\x9e.\xff_\xf0X#z$\xc5\x88[\xfa\xd2\x9fu_\xe7\x83g\xd85l\xec\xad\xd5\xe2\xfe\x06\xdf\xd9\xa7\r'
        b"\x98\x13\xc7\xff\xdb\xf5\xa8\x10\xcc\xb2\xb4*T\x85\xe9\x0em\xf3\xbc\xf5u\x06\n?\x1b\xff#C.\x1a\x00J\x8f1U\x99\xe4\x13\xa9J\xfe\x9emvE{Y(\xb9\x14\x1bD\r\x8c\x8e)\xea\x00_I'\rM\x9a"
        b'\xd6\xdd\x10\xbd8\xeb\x02\xdaTO\xf5\xaf\xe1\xa3\x06\xf1\xdf\xefC\xb7j\x91e\t\xbdf\x10\xe6\xf4?\xa3\xd7\x14O\x1f\xc6/\xbf\x93\xcf|\xb3\xba\xe9U\x1bG\x8d\xc8\xe6Z\xa1%P+\x89\x10\x8c\xf3\r-\x93\x85?'
        b'zVn\xd1F\xd0V\xf1F\xeb4\xbe\xc1\xf0O\x80\x07-\x12+\xa5\x83\xc2`\xfe\xed\xb5\x1cA\xa4.\xdfDd\x8e\xc6\xb9R\xc4\x16ny/fk\x91(\xe7\x1fZ\x82\x82Q\x01\x92\xc6\x10\xd0yf*\xb7\xd8\x8f'
        b'?\xca\xd8\x91\xb3\xc4\xcc\x0b\x16$\x07\t\x91\x90b4\xd0\xc4A\x8a\x12.\xa3\x8d\x8f\xe4o\r\n\xea\x81\xff\x81\x13\x90#S\x81\x07\x97\x87\xea\xd8@7M\xa3\xcc\xb8\x83\x92@\x9c\xb7\x92\x05\x90KT\xec\xb7p\xb2\x83'
        b'\x1dby~\xf80b\x08\x14\\M\\\x8d%\xc0\x7fa\x8a\xfc$VUd\xca\x92^P\xa5\x022\x13\x16~\xf352F=[\x0c\xe6\x90r\xa5\x1d\x1c\xd9^[\x0b\x0c\x100)\xab\x8d\xed5K\x00\xa3\xe7\x83>'
        b'\x83N,\xd1\x18\xab\xc6\xc0\xf6B\x95\x00Z>\xdb\x89\x8d\xa6\xdb\xfa\x89\x13\xbe\x15\xa4\x97i\xd53G\xb5\xa4\xc4\x99\x07TR\x8b\xc7\xb20:\xdd\xe6E\xcc\x80e\xb4\xb4\xb4\xd1\xa8;\xa9$\xea\x8f\x98\xa0\xd1\x89\x15\xc0'
        b'Cr\xd4\x1a*\xa7r,\x7f\xd4D\xe5b\xd7\xa1\x90\xba[\xcf\xf7\x97\xc2m\xca\xbd\xf2\x9d\x96j\xb3\x01\xf1\xe6\xbf=\x1b\xa4\xc6.\x99\xe1\xf7\xbd\x13\xb5\xb9nl\xc1\xbf\xadG\xecG\xae\xf8\xe8\xea#\xf8\xeb\xd0s\xc3'
        b"\xa6\xae\xa94\xec\x8d\xac\x06\x03\x1d\xe0[\xd9\x80\xf7\xb7L9\xc9\x97\x84~\x1a\x9d\xa3\xb6\xdb\x96\xbf'\xba\x01\xe4\xe6\xc0\x011\x9c~\x1dQX(\xf9\xd9\x8a\xc5\xd7\x91\x07\xd5\xac\xd9\xb8\xc5)'\xf2\x06g'\xfb\xc9+"
        b'\xec\xf4\xee%!\x9b\xe0\xbbT$\xcet\x02z\x7fg\xb0wI\xd8*\x03\xc8P\xe3\xd8-M\x81lv\x8b\xee\x91\xc0\x88E,\xa2\x13\x8d\xe6\xa2\xbc\xec\xe6)\xe2\xf1\x9c_\x03\xa2N\xf8\xcb\x9b\x94\x1f\xe2\xb9\x85\xf6{'
        b'n\x9d\x7f\xf0\xaaJ\xd7\xe5\x9beu\x02\xe5\t\xa0\xa0\xce\xe79*y\xe9\xf8"\xee\xea7s?\xf7v\xf1\x98<\xe3y\xf7\xca/7L\x07\xa8\x1c4\x94\xa9\xb6\xd9\xbf\xc7\x90\xfc(\x8d\xdbz\xf9\xccA\x9b#\xed\xda'
        b'\x89\xd6*\xcd\x11\x81H\xbb\x83\xa2\xa7\xd2\xa4thWP\x11\xfc\xfd\n\x7fg\xc1\x02I\xdf\xb0\xd5\xeb\xef\xbf\x19$>ni\xabNB)o\xc0\xbfxY\xdal\xe6\xb4O\x03\xfcVh-\x82/e\xa1\x81H\xf5\xec'
        b'\x00\xc1\xfc\x9a\xbfg\xa3\xbb\x05n?i\xca[\x13\x96u\xf1\x01>s\xbc\x0b\x03\x82\x1c\x13\x1fj\x97.7\xde~\x120\xd8\x9f[W*\x00\x16\xf7\x00\x88X\x0e9\xa12\xe4{\x16\xd2!~\xcd"\xad\x82b\xdd\x06'
        b'\xa9\x86r\x1cr\xc3\xba\x8f*\x0f\x8f\xc4}\x88\xb6n\xf0\xa9\xe8\x96/\xe9\x00\x96#\x8b\xb3ip\x92 \xb1\x074]E\xca]yy\x96\x99\x96\xb1f\xc0\x88\x1f\x17${$\x00B\xc8\xe2=\x94h\x93\x1e\xf5b\xe3'
        b'\xff\xd9\x95\x173\x8d\xbcJ\xa8\x14nS\xf9\x16\xbd\xbby\xc5QXB\x11\x90&\xc2C\xdf\xd7\xc9\xc4\x16kJ`\x8eg\x16\xfc,\x86\xa4R-\t\x16P7\xcb>\xb4Y>)U\xc0{\x81\xffl>\xf4o\xd3L'
        b'R\x93\xf3e\xc80\xce\x82]\x93\x9f\xae\xf4\x08\x1bz\xbf.\x9b\x0e\x0f\xbct\xdd2\xa6\xf2\x00\xa9\x80\xab2<\xbdld\xcd\x022tC+A\xb1\x801\xdf7\x80\xe2\x85H\xc4\xd6\xf6\xb9\xb3\xf24JTZ\x8dD'
        b'\x02\x00\x89\x8aqK[=b{\xff\x0eZu\x80\xd2\xc4\xac\x9e\xaa\xbd^\xbb\xb7\xb1\xc3\x1a|\x83\xd3\xa6\xc7\xfc\xc4\x0b\x92=E/\xd3H$\xbf\xc8\xe7\x86\x8e\xa9\x91K\xde\x0f\xd91b\xb7\xad\x02\x03vc\xb9 \xd9'
        b'\xa9\xae\xa2\r\xa1\xee\xfcL\x909\xd6\xda\x90-l\x12(S\x8a\xc0\xbeE4\xd3\xaf\xaa1\xcc\x91\x1e?P\xc6\xebU\xdd\x16v+\x1d_v\xd6\x18\x7f\xf9]\xcd\xf7\xe1\x1a\x87.+>\x86\x10Q\xcb\xd8./\xb5\xec'
        b']*\xfe/\xa5\xe7\x16P\xc9\x1e\xc9ei?\xa8<F\xb1\x8ct\xcf\x9d@\x19\x91\x02\xbbYv\xe2\xaa\x8a2\xd5}\xc2\xa9J\xf4\xda\x9bS!\xce$.]\x965w\x83%\x96\xfa\x9b\xf3\x9d\x0e\xa9\xff\xcf\xa3-\x8a'
        b'=\xd4U\xbe<\x02^\x8d\xf6\xe5a\x8c#\x94\x0fC\xeaB\xa5\x87\xf1m\'/v\xa0O\xff\x83\xcd\xf4\x08\x85\xc9O\x08\x84\xac6\x0b\xe1\xb7\x8f"\xecW\xb5s\xa1\x02AX\x1c`}q\xcfP\xd7\xb0\xe5uB1'
        b'5E\xfc6K\xa9\xd8e\xed\xdcA9\xd1\x81Z\xf0_\x8f\xfa\xcc\xb2\x89\x8b-&=\x85\xcb%\xa1\xe3\r+\x87\xb9\xd9I:\xba\xcc\x9c@\xf8\xa5{\xfdq\xb4\xda\x8c__\xc7\xa4\x8a\xce\x12\xe5\xe6|i)\xf9\x1c'
        b'\xfa\x89>b\xe0\xf5SI\xe4\xb1\xd7I\x07=\xdd\x8e\x9d\xd0\xa9\xc9\xce\n\xfd\x16\xf2\x80|qz\xf6FD=E\xe4%&\x12\x00\x11\x96\xe7\xca\x8d\x17o\xef*\xc4xeY\xac\xd6\x07\xe3\x91u\xae\x95\xc2\xffS\x12'
        b'\x1a\xb0uI\xc1jJ\xa3\x19\xd6\x08i\xfa\xe3ek\xa0\x1flt\t\xa6\x9f\x8a\xfd\xcc\xd0\xb4\x97FN\xad\xc1\x06\xfd\x13)\x1c0\xa2\xf3\xf9\x9c\xb3f[\x7f2;?\xc3\xe9%\xcdt\xd3.B22:\xdeE\xad'
        b'\x04\xe5$3\t\xc4\xe7\x8b\x1e\xb6W\xc6\xb8DI\xab\xae\xb2<\xa8\xd0\xd9!\x12kGd\xaf\x1d\xba\x8fE\x022\xae\xcc|\x0c\xc8/\xea\x0b\xfd\x16F>=}\xca\x95"[\x06\x88\xa1\xd6\xe4\xc8g\xb6>\x86\x91O'
        b'\x9e\xf0\xb4j5I\xbd\t\xeeKb\xf4\xf2\xfb\xf4[/\x83\xd5\x9a\xa3\xbe\xd9l\x14\x99\xa4CW\x12_}\x89fV?Dz0\x7f\xc3.\xe9\xc56\xf9\xf9!\xb8({f\xbd\xa1Ib\x10U\x16\x18Q\xcb\x88\xcb'
        b"dn>\xdf@0\xf6\xccx\rZ\x968\x05\xdb]\xc05\x17\xe2R\xb6\x04\xbf\x9b\xdc\x8b\xb5\\Zu\xb2~@\x1e\xa6\x95\x96\xaa\xd8y\xae\xd5\xfd\x1b\xca\xd8\x8a\xcb&G\x95'\xf9\xed\xbf\xa5x\xa3\\\xbfL\x9dz"
        b'r2<\r\xcf\xbc\xb1.\x1ad\xc4l\xee\x88\x04p\x12\xe3\x9b\x8f1\x9c\xe3\xac\xecb\xa1\x0c\x0c0(|\xe8\x1fY\xe1\xeb\xf5K\xb6P\xact\x8c\x1c\x8e\xaf\x1b\xca+g\xff;\xf3\xb0Q\xaf\x123\xa5\x9c\x16GT'
        b'\x86He\x0e7\xcc\xf0\xe7\xd4N\x9dr2Y\x94\xd3\x11y\xf8\x8d\'\xb6\x8b\xe8\xb8\rad\xa1\xf1\x92\tk\xfc\t\xa7\x8dk\xd2\xf2`93\xb2\xda\xec\xd6\x0b\x16~,"A\x19\x0f\rrO\xe4\xc7\x14\x90d\xd3'
        b"4\xb5\x01:]\x99T\x9c'\xdc\xa7\xadKj\xee\x19\x82\xfbbL\xdc\xa1\x90U\xd3\xca\xef!\xe2\\\xc458\xfb\xbei\xac\xfc\xd6\xcc\x88\xc7\x7f\xc3\x11=\x03\xb1\xff\x7fq/\xe7\x93j\xbfB@\xe0ri\xa3*\x15"
        b'}\xb3\xe8\xa2\xf0[$O$a#-O\xa5Z\x1b\xb1\x86\x9e\xfdD\xb0\xcc\xe1\x16\xd2\x805\xac\x95N\xe2\x19j:\xfd\x17P\xb1>\xb6\xb5w\xd4\xefm"#P\xf4\xae\x0cE\xbaje\x9c\x00\xa6\xf6\xde\xc4X\x82'
        b'2\x97H\xc7%\xc4\xcc$x\xa3=>f\xa5\xb6 \x18\xb7m\xcd\x14\xa9\x83\x1c\xf2\xdb^n7\x8dvs\xaez T]\x86T-\xe2a\xf8\x12As\xe0\xf9u\x88El2\x87/\x97\xe0\xa4\xf9a\xde\xf6\xfe\xf6'
        b';\r\x8a\xd2\x16\xc8k\t\xad\x04\xcf\xfa\x1d\x9e\xc8\xa85j\xc2j\x88\xd0\xe9\xbb\xc6\xad\x93D\xc9\xe3\xe7\xe3&o\x90H<\xa1G\x8e\xa3\xdf\xf3|U\xb2\x19\xcc\xf7$}\xedh\x7f\xe1\xfb>xj\x96m)0\xf9'
        b']\x8f3_G\xfbk\x0c<\xd48\xf2\x93\x96\x0c\x92[\x9b\x11\x82\xc8&c\x84r0P\x0e\xeam\x10\xdbg\x1c?|lBq l&\xban\xf7<U#i\x1a\xa3\xb9Z\xb5vN\x05#\xc7\xb6\x99\xb7j\xce'
        b'\x12\xe8\x93[\xccZD3\x93\xffx\xfe\x07\xd3\\\x9c0\x82%\xc8\x00\xb3\xad{nF\xf0\xfc\xd4\xc0gf\xd3D\xa9P\xe9UM/\xbe\x93\xc8\x85\xfeh\xb1\x04\xef\xec\xbaTf\x13\xfe3~\xd6\xa2%!\xf3\xf2\xe5'
        b'\xf1\xc8T]\x92\x0c\x17\xfdz:lt\xe2\xba\x85\xd2\x11\xd4d\x97c\xff\xa6(\x9cSK\xcfE\x00\xbc\xd8\xa1\xb4\t.\x8b\x07\xff\x83 K\xa0\xed\xe7\x93\x02fq\xb3\xb3\x9f\xbc.\xfc\xe4\xa7\xa7+o\xc77-\xf2'
        b'Q\xdb\x9dl\xf1\x83M$\xe4\xe8\xa1\x0f\x87\xdaYL\x12-\xe0\xd9m\x89\xe0s\x93\x83=\xa1\x97~\xc4&\xde\x9e\x0eK\x038E\xe5.(s\xce\xd7\xbf\xc2\xc5"\xfb_ !\x83\x9a\xf5\x11\xcc\xdc\xf6\xfbs\xd4\xae'
        b'\xc8\xe2{b3\x9bQr\x1b\x8c\xd6kmr\xdc\xe1c1\xaaT\xb1\x018\xec\\W\x03\xbdi\xdf\xc2g\xe2\xfb\x7f\xc9j\x8aU\xe1\xce"\xf3tPPkMs\x0e\xc9\xe68\xc2\x12\xfbg\xc2\xe3\xec;\xce2\xdc'
        b'\xd0<\xd3\xc3\xe0S[t\x19\x04\x92\xb0<\x8d7\r\x87\x80\xa9\x84v"\xe9\x85)\x90%\xba\xd0\xac\x9c\xa1\xeb2\xb5M\xccAq\xdf\xfb\x85a\xdf\xc1\xc0\xaf\xfb8\x08\x0c\x1e\xc4M\xffZ\xebcC!\x03<\x9fs'
        b'\xf6\xe4\x96\xd0\xd3\x8d\x99s\xaa\x16\x83\xc0\x96\x1f\x0b\xf4\xb6^\xca\xca\xbb\xad\xd6\x10v\xafl\xff\x8c\xa3\x1bs]\x17S\x9aT!\x95\x87\x99p\xbbhU:g\x06,!r\x1c\xf35\x06?\xe4W\x94\x80\x15\x86>\xdb'
        b'\xdf\x9e\xba\\\xb1\xd8\xff\xb6S\xa4$\x0c\xb6\xae3\xde\xbb\x90%\x94\xa5o\n\x0f\xb0\xb2\xe65/\xcd\xa9\x13\x9a\x84\x06\xb6\xb9\x88\x1d"\xc0\x03\xce\xc6|V*H\x03\xaf\xdcM\xb86\x85\x11L\xde5\xda^\xac\xce\xb3'
        b'\x9f\xd6q^x\x1b\x15$\xd5D\xb2\x81|\xa9F\xc1K\xac\x9bI\xcdGJ\x8b\xcc\xdd_\xce\xe2\xfao,b\rXlH\xa4\xbd\tA\xe9~#\xd81%_\xce\x16\x9f0G}\xb2\xf1\xc7E\x16\xa3\xea\xd2\xaa\x9c'
        b'\x9f<\xa8\x8b\x97?4i\xae\xf5\x98\xd7\n\xfbI 5\xb0ef\xf8\xaa\x10\xd7\xdf\x99\xa2\xe4m\xe3\x15d:v\xf3c#\xc5\xb2m>\xd3R+[ZV\xa4\xbe\xd2\x19O8U\x8e\x98\xbe\x1b\x03\x1aP\xc2\x99M'
        b'`c8:j0a\x93\xd6\x10\xfb;\xa4t\x990-\xfd\xd7\xd0\xe2\xe8R\xa2M<\x05\xc7\xd8\xbf\x13\xd1\x98n\xf2X=S\xd1k+\xc5\xec~\x10. gs\xdd3\x91\xd7r\xdd\x19f\xcd\x8e|\xefI\xb5\xd5'
        b'\x15\x12\xe4\xa6\xf1\xc7\xd05c\xe0q\x9b\xfc)\n\xe8\x97\x1d\xe2\x051\x08G\x10\xd5\xd9y\xd0_\x02\xe7\xca\xbb\xb6\xdeH\x98\xad\xe6\xa9[\xd3\xb4E\x157\xbd{\xd5z(\x8e\x80\xa0>v\x88\xa8\xa1\xbemX&6'
        b'L\xb5f\xea,\xf1\x11Ca\xe5lE\x84\x94\xf8\xce7\xbcQ\xaduq\xd7_\x7f\x0c\xad(\xe3A\xedw\xd6\xa5\xe0`\x98\xcej\x88\x84\xac,\xa5N\xe9\xabeD\xece\x8c\x8e\xd9W\x0bpg\x07\xe0\x9c\xff\xd5<'
        b"\xc6;Aosz\xf3\x9dY\xec\xf3\xdb\xee\\\xc0U=|\xd0a\xe1\x07\xed\xfd\xa30 L@\xaa&\x9e\x1f`\xab\x18\xab\xbb$\x1c<\x83\x9f\x0c\xd6\x9bX\x1f\xf3n\xe1\xafy\x8d\xd8\xc7\xae\x9a'YJ'\x80\xeb"
        b'\xc1!a:\x81\x04\xceC\xbc\x89\xbf\xe7\xce\x86\xf2\tg\xba;\x8e\xa5je\x8c\x88\xd1\x9b\xd5\xc5\xe7\xb8pCoI\xe5\xd8\x15[T\x8f\x9f\x80\x80&\xcf\xbb^\xad"}4\xce\xf0&\xc1\xf8!\x9f\xc8\xc87\xd4\x0f'
        b'\xba\xba\xbb\x83>\xed\xc4\xdc\t\x95\xfb\xd3\xf0\x14\x02{\xaf\xb6\xcb=\x16\xe0\x03\x07h"?\xbe\x14\xc6s\x0e\x8c\xff;\x1b\xb9\x04\xe7\x15\xd3\x1c9\xf7W\x9b\xe1=\xc1\x9d\x8f\x0e*\xa9AZ.k\xf0\xfa~\xaa\xebk'
        b'\xa6\xa8\xe5\xa9R+n\xcb\x9di\x82p\xc8k\xe2\x8b_w_\xa0\xe1\xd9Y\xcez\xedk\x1fk\x8c\x94\x99\x91n\xb0\x02Yw\x19L\xba$PDz\x1f\xdd\xe0\xe8\xca\x14\x16sO\xc7x?\xbe\xf3W\x98N\x9cn'
        b')\xad\xec\xcc\x9e\xe3\xc7\xea\xbb)\xc0\xf6\x120\xef!\xb5\n\xd3\xb3\xcf\xfe\xd2\xa1\x8d]\x02a\xdd*=\x8dBR\xda\x99\xd44"\xb60\xe8\x89\xbe\xd4\xeat\x03\xe5\x9a\xc4\xf7\xfa\xf2\xf50\x87F\xedz\xb1\xa9A6'
        b'\x03\xb5\x98\x87S\x13\xf511\xa1\x19\x8at[k\xfb~\xc6\xc9KI!?D$\xc9\xa0\xb7\xac#\xf3\xe9\xa5\xde}\xbd\xfeh>\xd5S\xd9>\x98\x8f\xf6*\x06\x95\xd2=.\xcc\x0e"\x03\xf9\x80o\x16\xebW\xcd\xfe'
        b'\xad*#qJ\xa3\x1a\x8a\x031\xde\x02\x1f\xd4D\t\xdd\x00\x19C\xd9\x16\x83\xc8\xebdri%\xcf\x04\xe5\x19\xa72_\x95\xd8S\xa8\xf3\xf4fW7\x0f\xab\\e\x04\xd0f{\xbd_\x1eS\xcc\x16\xe1\xe39\x93\xb7'
        b'\xeb\x0f\x8128e,\x7f\xdc\xcfx6\xf0\xe7\x0b\x19f\xa2\x15\x04 ?\xd1\xb2y*_I\xbc\x84\xad\xf0\xbaf\x04\x7fk\xa6\x1a\x02)\n\x8e#\xa4|\x02\xa8\x82\xfc\x9f\xb1dqA6\xa0\xf5\xd8\xa4\xe4\xbc\x9d\xb3'
        b"~'J\xb9gc\xbawU\x9f\xfd8dE\x05WY\x9e\x1e\xd3\x83\x9bP\xa1\xef&\x86\xc0\xa8\x95\xc2\x1f\x85\xd3\xafD\x98#29T\xbd\xeb\xf5\x01\xfc\x14\\lc\xeb\xab\x07\xb4\xe4\xbf\xf3\xf2Ab\x14\x1c\xce\xe1"
        b'\x1cN\x80\xe5\xfd!B\xb7H\x11\x05\xf7\xe0\xaa\xb1E\x80\xc9\xdd`Ye\x8c/\xfc\x1f\x1bW\xfe\xde\x81X\x17\x17D\xbb\xdb\xf8t%9\xa5\x8fV\xe3\xb4\xb7\x9d+y\x9a4\xf1\xa4\xbcI\x03f\xae\xc5\xd9l*\x0e'
        b"\xe9-TN\xd2.p$\x1e\xbe\n\x8b\xd4O\xb9\xc3Q\xa9\xb3\x11\xed\xe7\x1c.\xfb\xe9\x19\xa4\xd9H\xf26\x95\xcbv|\xec\xd7\xc5\x0c\x8d\xe6\xf0\xa9\x85F\xd2\r\xd1\xa5\xe3\xde\x13GiX\x96\x8a>\x13<\xcf'\x8b"
        b'n\t\x8c\xb4\x1f\xd4E\xea#\xaaoR\xd2\xcd\xbd\xac\x1c\xa7Z\x1e\x8a\xfbNC\x92\xfd\xda\x075\xfd\xa0!f\x93\r\x95\x96\x9d-\xdc\x01\xbb#\x06b\x9d\xc6|\xab\xc0\xea\xff\xb5vw\xf3\xea[f#\xb5ah\xa7'
        b'\xc2,\xccXo\xe1?\x0c\xe6_\xdaw@Q\x17\xc4\x84\xf2\xb8vF\x97\x91r.\xce\x18\xbb\xb2\xd2X[\xf6v\xde+pOl\\\x14\xe5\xc8\xb4\xf8"\xe28r\x837\xe6\xfd\x87F\xa8\x02B\x03-q\xd4-\xd2'
        b'\xe3$A\xd7\xdc\x1e\xee\x88\xfc\xb2]X\x10\xdc\xbb[\x04\x01\xda\xd7\xaee\'Z\xc0\xf8\xe47\x0c\x9b/\xe0nTH\xdc\xa1H<\xa0V:)\x0c"n\xf1\x87\xffx\x99\xd0\xbc)\x15\x03BC\x8b\xed\xe1b\xdb\x1c'
        b'Phf&.\xa9\xcf\x97_\xa6]\xe5\x1cn\x9c\xb8Y\r\xab\xbe\x98\x16\xa2\x03w\xc1\xd9\xc7\xb9\x95d\xef\xa7\xeae1C\xa8\xf5\x94\xc2f\xe8\xfd_oz\x9d&F\x14\x90R\n\xdf\xaa\x87\xf4\xb3\xb3?\x97\x8fM'
        b'\x03\xe0\xd1\x03\xb5T(\xf5\xea\x1f\x0eH4\xff\xb3[\x13-\x82\x01\x84\x85\xc0f\x92X\xbdI\x97\xe9\xb9\x85X\xa2\n\xb5\x08\xf3\xe8\xc6*\xaa\xa5\x00\xe25\xd9\x00\xefek\xbd\x02\xd7F\x1e\xdd\xcdd\xa4\x84{\x9cp'
        b'\xcd=\xac>^\x15\xa8R\x00R\xce\xc7\xa60\xce%\xbf\xf2\x84$\xab\n\xa6k\xc3\x97\x99\x02+pty\x1fGS\xe3\xbb\xab\x9e\x86.\xb4X<\xc4\x80n\x84 \x98\xf9\xf8\xf6\xa3\x84\x9a\xb7/\x18\xd0\x8a\xa3D\x8c'
        b'G\x1834\x0e\xbc\xbbG\\\xb3\x19/e\x9f\x9a\x8a\xdb\xf1G\xa5\x9f\x9d\x91\xf1\xff\xa7_\x04E\x97zv\xaa\x9b\xd6\xc3c*:\x9b\xd2\x8e\xa7\x15Z\x85\xa5\xb7\xa5\xb3\xd4/\x86K0\xd4\xdd\xb6\xa1\xd2\xb5s\xc6\xe1'
        b'\xb8U\x96\x88Hxfc\xa6\xb8/\xcb\x96\x10VN\x19\xc2\x12\x82f9\xc6&\xa1\xe0\xf2s\x88\xb5\xeaQ\xf6d5\xe3EN\xe0\x9a\x19\xab\x83\x07-R\xea\xd7`2\xba\xe0\x99%\xc5\x8f\x0c\xa0\xa9\xf8\x96)\xbe\x1e'
        b'g\x05\x86\t\x12W\xd81\x17b\xb9\x93\x10\x11j\x92\xc7\x98\xfa&\xd6\xc4\x84\xcc\xf1P\xb1\x8c\x08\xc3@+;\xef\x8b\xfd\xa9\x1b\x05\x99^\x8a\x82\xc8\xa1\xc2(\x90\x80%\x01\x17>\x9d3&\xe5k\xa6\xccJP:\n'
        b'xjY,\xbb!\xbep\xfbZ\xd3\x94zM\xad\xddQ\xea\xf1Kdz\x95y+\xa1a\xa3ii\xd5\x9e\xd9o\xb1\xe8\x95\xd1\x97l\xca\xe0\xf6v\x19\x914\xd7V\xf7\x19\xb7\r}P\x83\xe6O^\n\x83dQ('
        b"\x86\x91\xde\xfaA\xc5k\xe0>\x17A\xad\x1b\xfa\xfd\xac\xb4\xae\x9d\x0eC\x9f\xd8\xea'xwcO\tb\x8a\x05\xc6R\x87\xc1\x91\xe04\x1a\xf7\x14\xb6\x99N\x80\n\x9aPGp\xf6k\xb87\xd7\x19\xf9{}9\x85\x12"
        b'*U\xf7\xe4\xcb\x13\xec\x03\xe7s)\x93#1\xf9\xd9\xdb(\xdd\xd4\x0e!\xb7@\x8f_\xb2p\xd1R+[\xf0\r%\r\xbf\xdc\xb0\x19\x06\xe0X\xd7\xe9\xf9\xba\x89\x87\xa3\xd2\x95p\xbcX,\x84\x17\x8d\xfc\x7f\xa3\x7f\xf4'
        b'\rE\x1f\x8e*\x87a\x97\x9f\x81<\xe8\xb2\xe3\x985f\x88\x06\xd9;\x88\x100\xf2\xf2\x04\x86gCg\x14\xfa\xcdH\xf4\\z\x83Q\x04r;b\xe8B\xac\x13\x7f:ah#\n\x83~\x1e\x15\xdb\xc7\xf6\x00\xcas'
        b'<[\x92\xbf\xea\xb9\xa6\xc3\xf8\x16\xe3\x02|\x81aX]\xc5x\x8cP\x14\xc5\xa5\xe6\x8e\xa0\xb9\xd7YF\xc9\x0cK\xad\xed\xc0h\xfe\x16\x9eR\tP\xda#\t\x03\xb2\x90\x8d\xcf\xbd\x10\xcbM\xb7\xfe\xb0}\xdc\xa6O+'
        b"\x86\xf3\xa7\x9c\xae\xe1P\x00 #\x1c/m\x80\xf1\xeb\xe8^\xe1\xb8\xb4+\x0e',\n\xcd\x0f\x15\xbeH\x80F8\xa9TQ\x18^\xe0\xc2\x84\xda\xc2T\xbdw\x02D\xcaFQFCH\x19\xe6\xe7\x16\x80;\x10\xe2\x9e"
        b'\xc4\xb0\x9e\xd2\x83\x10=\x1d\x01\xda"\xd9I\x8f\xe3\xe4\'M{\x08\x8aM\xe7\xd05\x98D\xba\xbd\xfeD\x06\xe6"\xe5w\xcf\x9f\xa8\x8aL|\x04[\xef\x8dY#\x97\xd6X\\\xcf?s\xd9\xaa\xae\x9c\x0c\r\\\xcf\xe6'
        b'\n \x07\xbaI\xb77\x8f\x13\n\xfew5&\xaa\xf1:\x0f#\x80l\xad\x95\x82\xf4\xb2\xcbxnC\x08\x060\x16?\xdd\xfe\xae\xdb\xb1\x17\x9c\xc3\xca~[\xf2\x13\x10L\xa0\t\xe3z\x1c\x97\xc5\xa2\x06\x95\x90\xddZ&'
        b'\x04\xa3\t\xb9I\xf2\x9f|\x88\xb9\x8e\xe9t\xc3>\xfa\xa5\x9ck\x93}\xcc\xfb\xd9\xb541@>\x05\xe2#b\xd9\x0f\xb2\x0bv\x8f\xf8\xc7s\xae\xb2)o\x1fN.\x12\xcfVt\xc9\x1d\xc7\xc9\x7ft\xe1o\xdfd\x0e'
        b'\xb9y\x14\xe16,\xae\xd0\x11\xa4\xf5\xe6\xce\x87\x08\xef\xf0\xed\xe5\xc3\xe5\xaa:aN1\xae`v\x08s\x9d\xc0\x99\xc6\xb6\xd4\x88\x97\xf7\x1f>\xc6\x93\xee\x01g\x1e\xe7\xbf\xc1\x97h\xcc.\xe2\xb3\x04\xb4\xb3\x83H0\xa3'
        b'\xdaTG0\x03\x0e}}7{9B\xf9,\x16\x05[\xf9\x8dyB\x88h\xc4\xe4\xb0\x88\\\xedc2s\xd5\x9c\x04\xb4\xfab\xf4\xfa\xd7P_\xd7\xf36\xd8\xe6\x01\xec\x1e\x16n\x03\x16\xb4q*\x9c\x93xO\xd9@'
        b'l\x03\x92h0\xc3\xc8\x14\x8f\xc6\xc1[\x1d\xd3n\x90\xfb\xcd\xedL\xf2E\xcf(\x84\xfeIk\xe4D\xbb{\xe9\xd8\xa6\xd3\xbe5HZX\xe1;\xc3\x1f\xd4\xd3\xe4\\r5\xef\x08\xdc\xa9|mT;\x80_\x92XF'
        b'qC\x01\xad\x17\x82?i(\x1c4-\x1d\xdc\x0bx\xb3\xac\nHJ\xdcV\xdd\xb1\xb5\x1e\xb0\xf6\x84@\xc9\xf2\xb0.\x9b\xd9\x85\xec(9N\xe6(\t\x0fH\xd1\xf5\x08\x08\xef\xf4\x8du\xe2\x0b\xc6j\x8f\x05\x9c\xf1\x18'
        b'\x9ck\x17!\xe8\xeb\x92\xde6\xf3\x91\x95s\x18\xae\xfe\xcf\x96PV\x15\xcd\xb2\xc9\x95w\x13\x846\xb5\xab\x8d\xcdgv\\2\x8d\xd3\xc4\x03\xb9,\xe5\xd2\x02_iiYtFH\xda\x94/g\xce-\x85\x94\x0e.\x19'
        b'\xd9\xf5j"\x17\x13\x95B+\x96\xbaj\xf3\x10`\xcf\xd3\xe6|Mu\xd7ZKD\xfb\x8eA\x90l\xb2\xaa\r\xa7B\xc4\xf3\xdc\xfa\x11\xf0!\xc9\xf6u\x053\t\x99\xf8\xe0\xd6\x98\x03t\xf0\xbb\x15%m\x9b\xec]?'
        b'\x8c.\x91\x08\xdc\xb9\xbc3$Ze#\xa6\x1d\xbb\x8c\xf6\xc7\xb3\xea\xa1e\xc3\xb6\xf2\x05\xdd6\x12\x80\x19e\xad@\xeb\xca\x07J9\xf2\xa9\xdb\x83R)/X\xc0\xa9\xb9\xb0Q\xaa:\xc0o\xa7k\xb3 r\xea\xecc'
        b'\xae\xc4=\xac\x12\x14\x96\xaf\nVs\xa8\xa4kj\x7f\xe4\x1d&\x83z\xa9@N\x05V\xee\xa8i\x9fWT8\xdb\xaf\xee1\x1b\x02\x94\xcb\xb9I\xf8<LZ\x81;\xd6A\xb0\xca\xefI\xaa\x8co\x9c\xfa\x11\xee\x16\x07'
        b'\x99gWgS\xcb\xe0\xf4\x95\xd4<\xcad}\xf5\xae\xb9\x90\x11B\xa0y\xaa\xb4\xeff`\x05\xef\xe5\xa3\xb9c\x04\xcb\x9a\x9b2wm1\xbe\x7fv\x10\x1c\xde\xe96\xd8a#\x8f\xa3\xed\x81\xb3\xf5\xdb\xfd\xdfaw&'
        b'\x83\x95\x10\xae9\xbf\xa77\xa7"d\x92\xec\x99\xb6\t\x10\xec%\xa9$\xf2\xe7\xfc\x94[\x96\xce\xcd-\xd5\x00{X\xf3\xd7\x1av\x96#\xdfI8*H\xff\xc9\xc5\x9d\xee$<\xc6Qs\xcd\x1df\xbfe\x87\x16d\xc8'
        b'\x8c}[\xee3g7>}\x0e\xa4\xfc\xb7\x10\x90\x97-\xae1\xfb\x96aBv$[\x051\xfb*\xb7\x04x\xa9\x15\xfb\xa4^\\\xca\x13\xcb\xc0\xc6~\xf6\xa4\xc51\x98\x84\xa0\xb9?\x1a3\x1f>\x0b@\x91\x03y\x0c'
        b'\xa8AU\xc3_\xe1\xbbfse\x1b\xff\x0e\xc7\xba&w\xd7%\r\x81\x9e\x0c\x99\xc2\xa2\x99\xe9\x9c~. 6\x13\xda>5\xe3\x88q\xf0\x7fvw\xefP\xe5\x8fV\x10\x8a\x14\x0b,s\xa8\xfe\x0c\xe0\x87\xb3_\x12\xc8'
        b'\x919\x17\x8c\x03\x0c%\xdeQ\x86\xd4\xbd\xbc\xe4\xeb\xcd\x91\xac\xde\x81\x1d\xa3\xc6\xe4b\xea\xd3\xa5\xd8\x83\xc4+k\x1b.b\xd6\xb1|\xbd<\xf7\xe5\xc8Q\x98\xfdX\xc5\xb5c\xa4;\xf2\xd3\x8e\xbcU\xe4\xb3\xd0P\xae\xf8'
        b'0lm\xb8W\xbd\x04\xa3\x87\xb1\xbe\x88\tB8$,\xb3\x9ce\xa6\xc6\x16b\x16\xbe\xbfH\xdde~\xa8\xd4\xe4k`oKq\xb8\x89\x96(bX\x81\x14"\xd3\xc27\xb3\xd0jcW\x01\x18\xc9\x15\xae\xd9l\xc0'
        b'\xedY\nw,\xafDo\x8e\xb1\xe3\x1f\x1d\x9a\x85\xf9\xa6\x03R\x0c`\xc4P#e\xad\xdbEY\xc3\xa0J\xe4qE\x1a\x10\xec\xfd\xc6ds\x81^\xb5\xf2E\xe6\xdf8\\\x98\x05\xbd\xf1\xfc\xf7\xdc&\x94\xbcwc4'
        b'\x8c;_\x9b\x111o&&\x82\xbd\xfe\xa1\xa54\xd2\xbf\xd1a\xbeT\xbb\xbf\x8bD\x13\xefl\xe2\xcf\xec\xc8\x02\xea\x8d\xf4\xe7\xd5\xd5\xbbO(~8P\x05\xa2\x83|wqT\xb00\xfd\xed\x15\x05\\\xc3h\x9c\xf9\xad'
        b'\\&\xc4\x00pW\xfba\xcd\xb6\xfdu\tH\xd2\xa4\xd7;2Q4>>Y&\x9dC3F(\xbf\xf3\xc71\xcfm\xb4Ll\x05\xd2\t\xea\xdf\x7fH^L\x16\xbd\xd8h\xa2\r\xe1\xf8\xa4\xd0\xa3\x97jCs\xc6'
        b'\xd0\xcbJgb/\xa7n\xf8G\x01\x88Z\xdc\x00\xab\x04\xc7\xe3\xf6\xf2\x08\x93E\x9f\x83!\xd7<\xbf\x14\xaeuAf\x83UZD<\xef\xee\xec \xc27\xbaN\xceN9\xf8\xf2\xff1W\xc5\xe8@\xad\xa7\x9e\x08<'
        b'\x96T6\x87\xe54p\xe4\x93\x02\xfflX\xf4f\xae$\xca\x879Co\xd5\xa4\x13i\xdd\xa9lv\xdc\xc5a\x98\x06\xe9k\x01],z\xdc\x0cC\xaa?M\x0f\xb3\xad\xabxB\x94\r\xf1\x19\x86\xd0\x9aB\xd7E\x04'
        b'\xf1\xe8V\x7f\xab+\xd5\xd8b\xcd\xc8\x1f\x9dh\x1c\x029\x81\x98\x17\xd9{\xaeiC~\x00U\xc3\x00\xc0\x0b\xd1\xb8J\xaa]\x84j>\xf0\xf3h\x08\x95\x81\xd7\x89\xdbi\xed\xab\xf9\xae3h\x94p\x04\x0b\xed\x8c1\x02'
        b'\xf8\x048P\x8d\x83\xe3\xefD\xdf\x18\xf3\xeb\xbbb\x07\x06\xa2\xd3\x13\xa2\xa4^\xbc\x19?\x9d\xca\x8e\x839\xfdc\x1ba\x0b\xfd\x068\xb36=\xa8\xee\x9b9\x90\x7fuX\x86\x9aK\x8c\\\xb9c\xdb\x19a\xfd4j\xc4'
        b"\x084\x9e\x83\x03R\xdcM\xbb\xce7\xcc\x80P\x1c\xda`\xcfD\x04\xe3o\x83\xa0\xc3\x96\xfd\x95<w\xf3\xf3\xa1\xfa\xea\xa1\x90\xea\xbfp\x9a\x03_\xb6\xdd'\xa5\x93\xe7\xda\xb3\x8f\xbc6\tPiF\xdf\xd5\x9f@px"
        b'U\x12\xeb\x8e\xeb\xce\xe4\xdch\xdc\xff\xbf%\xadg\xda\xb7\xbeWfe\xe0\x9a\xc9\xc6f\xb47\x0f\xc1U\xa2\xdc4J\x94\xb7\xb8\xf3\xa9\x05\xf2\xc8\xf2\xe7\xcfP<-\x0b\x92\x17ek\x9e\xc7\xe1\x9f1\x8f\x15\xad\xf2\xc8'
        b'\xac(\xd4\x9f\x826B\xce\x84e\xa9\xc6a\xf4\xcc\x00f\xaa^\xbf*Tt#D}\rE\xd0\xc4|\xb2iH\xae\xb5\xf1\x03u\xb9\xccHA\x9c\xe2\xfdc\xb0\xf8-\x12\xfb\x89\x90\xdac\x1d>\xe7\xba\xc1\xe5\x1c\xe8'
        b"\xbd\xcc\xa5p\xffR\xb91\xde\xca\xfc\xb3\x93\x8a\x15\xa8e\xe7\xe3'#}\x82\xcb\xd4z\xd9)\xabD}\xd5mNe\xab\x0b(\xc9\x08\x80Dj,\x93\xaf;\xcc$zh \x93\x84\xfc\x8c\r\xd4G6^\xf0\xe6:"
        b'\x1f\xcb\xe5\xb0\x87\x88\xbd{~0\xd1\xad\x80\xeb\x86V,\xdd\xa1f\xbc\xb0\xca=\xa5\xdf\xf3\xb4\xa0U\xbd\x93gc\xde)\x1d\xa1_s\xd1\xceN\x9c\x1f\x95\x18\x94\xb5\x15\xf7\x9cD\x11\xf2]"Z\x08=8\xda#\x9c'
        b"3a\xfb9\x94[$\r\xc8\x84\xd7\xdc'?\x07\x08M\xd5\x19\x0f\x01Ke\x1d1\xda8\x13\xdcX\xaet\x8bq\xc7\x84\r\xe9\xdb\x8c\xc2\xec\x10\x9e\xf1F\xf2\x10aA\x88-\xa6[1\xecR~\xbaH\xa8|&8"
        b'\x15_\xac\xc3-D^\xb4\x18\x15\xeb\xff\xce\xd3\xbf\x97\xba\x1cE\xf3\xed\xe8ol\xc6\xcf\x01\xc4\xa4w\xa54.\xa5\xce\xa9np\xf2\xf0\xc6T\xf9\xa3T\x17Tn\x99\x95\xba\xadH\x0f\x01\xba\x98@\xc3p&\xddZq'
        b'\x87GoV\x87*\xe6\xd6\x9c\xeb\x00\xae\x81\xe7Zop\xdd\xa7\xae\x83\x85#T\xdb\x14\xc2\\\x9a\xb1\xea\xf9D\xad*\xa9\xeb\xd1\xdc\x8e\x14Y\xce\xe2\xd0\x11\x07\xfd\xec\x8b\xd3X\x93G0\x9c\x99P\xa9x\x1c\xd8\xc3\xef'
        b'\xb7j\x8ed\xfa\x80\xbcY\x03n\x88\xd5\xd7\n\xfe\x93\x81\xd7L\x19\xf9\xaa-=1q\xfc\x01\x0f2wX\xf3\xcd\xc2\xb0\xa9k\xe5^\x8eO,\r\x03E\xb1m\t\xcd\x10\xd28\x9e\x00\xca\n>\x0f\xbf\xd6\xf5\xbb\xb8'
        b'\xcdDE\xfb\xebG\xf1Y\xc8k<\x93\x9c\xb0Xay{\xa9\x8b\xeb\xbbm\xaa\x81\x1c8\x07\xf2\x1c\xac]\xe4\x8bK\xd7\x14\xa3\xfa[^\xa0\x02\xab\x89\xee,\xb6\x8dUh1B\xf3X\xd0\x17*2\xdd\r\x80\x0c\t'
        b'&7qg\x97\xc4\xba\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00'
        b'r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
