
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01d\x02\x83\x04'
        b'\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\t/\x00\x00PYARMOR\x00\x00\x03\x06\x003\r\r\n\t0\xe0\x02\x00\x00\x00'
        b'\x00\x01\x00\x00\x00@\x00\x00\x00\xc9.\x00\x00\x00\x00\x00\x00\xd1\xab\x01\xdb\x0f\xe8\x9b\xc2\xf9\xf3Q\xffbT\xd7j\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xed\x90\x02V\xfcC\x15Z,F'
        b'\xdc\xcc~\xc2=f\xea3\xf0\xee\x8b\xd6\xa5M4#\xe2\xca-\x90\xb5\x14#\xc1\xdf\xb8\x85\xcdS\x8a\xb7ov3n\x96\xc8X%}\x1b0\xd2\xbd\xfd\xdd#7\\\xba"&s\x8b\xf1\x92Vq\xa88\x05\r\xd9S'
        b',\xa5\xb9\xd4,\x86\xc3<R\x82\xe0th\x9a\xd7t\x92\xceJ\xcb\x18\xbe)\xecY5p+\xd4Bw\xaa\x9d\xa7\x8f\xd0D@\x19O\x19E\xe8\xa1\x0f\xad\xe6\xa8\xed\xed[\xb4(\r\xde\xb5\x96\x13\x15U\x1a\xe8\xd4\x1d'
        b'P\x91i.2p/\x12\x1e\x14\xaa\xba\xffg\xcb\xdb\xdb\xa2\xf9\xe9Bn\x86\xc0w(;\xb3(_\x0e\xa5\x19\xc2\x0e\xb8PS&\xe2%\xfe]X#\xf4\x97\x13g@\xd4P]\x10\x80\xf3\xd7^\xcei\x87:4\x93'
        b'\x9e?\xae\x9ev(\xe7i\xaf~\x9dc&\xc5\xc2\x89j\xf8\xa5Z.\x9c\xfd?\x99\x9b\xd9c\xf5\xfb\x83\x8a\x9f(\xcbYK&\xa2\x1b,\xb8\x81-\x9e\x8aq\xdeR\x11\x8eA<R@6.\x00:\x9b4\x95\xe82'
        b"\xf7\xf3us'\xfeZ\xa7>\xf4\x17\xc8\xf5\x02\x17\xd6+\n\xa5f$#\xa8\xaa\x8a\xb4\xe1\xf0\xe97?\x84\xb0\xc7N\x1a\x13\xc8\xe3\xbc\x87\x14O\x89\xc6\xec(\xd7:\x8f\xe8L\xae\n\x92p\x80F\xe5\xb5Lh\x01,"
        b"\xad!\xf6\xc9\xc3\xddnJ=\x8c\xc3\xf0\x19F\xbbO?vX\x1b=\xcd\x12\x80q&\x95F\x1a\xb9e\x83qQb\xf0\xb0]o)\xfaxZ\xe5y\x10'\xb9\x85\x12\xe9l\x80\xd07\x9e\x85\n\xa5\xb8L<\xfe\x06"
        b"\x97'\x92\xd6\xfb\x1eM\x9a\xb8\xba\x95.1\xa1\x90\x80${ |9\xf8\x14\xe2\xb1\xab\xc99\xa0\r\x84\x94ei^\\\x06^\xca\xd1\x1c\rV9Q\xb6\xde\xa7|\xb5\xe9\xc8\n\xb3T\xafZ\x14\xc17\x1dX\xa0]"
        b'oUSX\xb0\x02\xe5\x1b\xd7\xf7\xa53\xf5\xd5+\x8d\xdd\xc8\xf8v\x1b(\xef\x8f\x97\x0e\xa0#\x93\xcd\xe9`\xe5\x1c\xbd\xd8\xaa\x9f\x7f\x05)\x107\xea\xf1\xc0\xa94\x94\x05\xc8x\xdb\xa2\xcb\x18b\xa8\x93\xca\xedP\xd4t'
        b'h\xefQT\xcfy\xfe\xa0\x8a\x9bV\x8f`;\x9by\xf8\xcf0/LL\xac\x1f\xda\xc5Z\x95YQ\x97\x08\xa0\n\xd7)\xb1\x81\x97{\xdcl\x89\xe8\xbc\xae*\xeb\xff\x83\xf5\x8a\xfa#>K0\xa4\x83\xb6\xf8\xba\x10W'
        b'y\x97\x04\xb7Kx#\x1c\x97^\xfc\xab\x0bz\xd4\x87X\xd6\x18\xdf\xf3Y\xa9\xf5\xe2\x1dLX\xa2\xbd\xa0\x86\xc0H"Qq\xaf4M\x0ew\xd0\x17%\xa1\x05=\x19\x03\xef\x9e;\x84\xc2\xed\xbfL3\x90\xf8\xb6\x8ck'
        b'\xf8\x11k\xc1_\xd0\xefA\xc0\xfeG\x19\x81\x9akW\xf5\x85\x159\xad5I"\xbb\x95,,O4\xbeQe\x82\x9b\xbc\x0e\n\xe1\x82\xc9\x81a\xeemj\x1e\x12\xb9>\xdf\x9a\x1fW\x0fX\x9aj}\xad\xee\x16P\xa0'
        b'\xb7\xfb\'o;@K|K\x00\xc40o2Xr\xcfI7\x9b\xcd\xa4\x97\xbf\xc8\x80\x00!\xae\x02\x96\xf4W\xf4\x89\x84\xb9\xd3\xeccOVZO\xda"E\x13\xde\xab\xa0\xc0\x94\x9c;b\x87\xc4\xf5\xab\x93\xad\x8c.'
        b'\x1a\xe5 \xea\xbfVs!Uw\xfd\xa9M\x8d\x9c\t\xbfe\xec\xd7\x91)\x00\xc1\x14\xbe\x93i\x8d\xad_\xe1j\xd0\xb6\xc4\x02\x93\xd8\xc5z\r\xaa\x08\xbc\x94\x04\x85\x1ad\x9a\\>\xe5\xa7\xb5.r}6l\x97\x85\x11'
        b'>\xb8u\xe3\x956U\x1f\xd8\xba\x87\x04b \x1c\x89IU_\xef\xab\x10\xc4\xdfI\rm\xf8\x86=qZ&OE\x1bw\x02\x84{\xf2\x0cU\xdeV\x15\x88\xc5\xce\x8d\xce\xef\xa0+=\x93\x87F\xdf}}\x18\xfa\xc8'
        b'\xd7W\xa4<\x18<=f"\xd5B\xb9.uJ2\xc18\xe2\xe0\xae\xdb-{|I<\xb6\x0fv\x94\xcc\x92\xb0\xe1\xfa\xac\xda\xa1\x13=\xe1]?\x82\xd7\xd1c\xbd\xb3*$=7D\xf3\x87\xd5G\rL\xbb\xbft'
        b'E\x16\xc7\xb5~\x10[\xd6\xbc\xda\x9bu+\x8aN\x81\x87\xb9\xa15\x81\xb37h\xd3\x8b\xf5r\x98\xc1J\x81\xa9\x9c\xdfY\x9f]lx\xd3h\xf1<\xb2\xb7\xdf7\xe8s\xb7\xf1\x9d\xf3\x00\x83\xba\x8e|\xdf\x17\xd0\xfe='
        b'\xca\xde\xc0\xcaBEL\x11\x9e\xbe\x04\x01\x10n;\x80zl\xa4\x8c\x8f\xe0\x89k  \xa3\x9b\x82\x14\r\xa5\x9b\xb7tS{\xef\x80?\x8a6\x7f\xbf\xc2\xd9sJ\x06\x95\xac\x1d\xa7\x96\xd0\xe3\xee\x90J\xb2/#\xef\x81'
        b'\xb6\x93"\x80\x82\'\xb7\xd00\xc0\xe7!\xd6\xd5`\xbe?Ay\xf4\n\xf6\xa9#ib&S\xe35\xe3%%\xb9*\xef\xecii\x1a\xe3d\xa8\xd9\xf4\xd0\xd7\xdc\xde\x16m\xc0\xa8\x82\xa3h\x85\x07\x1aJ\xfc\x81\xc8\xb7'
        b"pxuZ\xff\x01\xa3:lV3\xe1\xa0\x81P\xa8\x88\xf4\xb8\xe2\x81\xae?G\xfci\x14\x16\x19fPr=\xa9Xx\xf5\xac\x9e'r\xee\xe8\xd9\xff\x13I\xef1n\xf4\xc9\n}\xa9c\x9d\xf2\x96D\xdbc\xbb\xbe"
        b'\xeb0\t\x96\xae\x142\x87\xae\xf4\xdbG\x84\xdb\xef\xc2\xda\xad\xb0\xb9\x87\x80P\xca\xe2X\xf5\xb8\xa7\x99\xdd\x8b\xd3rO\x92\x86c(Q\x19\xce\x860JdC\x05\x91\xffg\xb1\x84\xde\xba\xf9P\xe4\xef\xf2\xae\x83F8'
        b'\xa8z\r\xc2\xa5\x92A\xeb\xdf1-\xf3H\x1f\xb2=\x11y\x8d\x144\xf4\xcc\x83\x08\xa7@\x95\xf4\x98\xdb-9,\x96\xd2\xd1"D\xf0\x91\'R\x1bp\xfc\x8f\xa3,\x1aow\x97\xe7\x8b\x1fI*\t\xe4U\xa33\xb7'
        b'\xe0]VzX\x92\xacQ\xa5\x9a\xa6P\x03\xb2\xcd\xcd\xe9\xe4H"\x84.H\x0f\x1d\xcd\xaf\x84\x94\x06\xf5\x93\x0c\xb3U\xaa\xa4\x8c\xbb\xfe\xaf\'\x92k\x9d\x90ua\xee\xfd\x11\xff\x05\xc8\x08\x0e\xb01\xb0\xcb\xa3\xaf\xc0\xfb'
        b'\x90\x08o\x91E\xf1\xb4^\xf6\x9f\xb4\x07s\x93\xcc\xcf0~\xdf\x1b\x80\xbc\xf5\xef\xbcl*|\xad\x98\xa5x\xc4\xc0Mm\xac\x82\x99\xee\xb1h\x01\x06o~^\x86\x06o_\xe3\x82\xd3\xee\xa5/\x0f&y*)}\x93'
        b'\xd7\x19\xb1\xd77(\xb7\xc5\xfb\x05\x8e\xb5?\x91\xa7\x8b\xbf\x9c\xfb\x96\x90O\x13y9wKb\x14\xb9\xb0nm\xf5a\x83I/\xb6G\x16\x07\xf4\xaf\xbfC\xfb`\x95\r\xd5\xf1\x81\x8a_u\x00\xed\xf8\x9b\x1b\xa0\xfdg'
        b'\xc3B\x92\xd5\x1a\x05\xc5A^#{\xe4\x0c\xb9)=\x153\x9f,9\xc0\x9d(\x0cV\x8b\xd4W5\x15my\x1ddBe8^\x9f\xd9q\xadvU\xf3\x8c\xfe\x82_\xc3\x01\x1e\xed\xaa\xdb8\xce\xf1\x95\x1e0 \xed'
        b'\xb1\x0b\xeb9\xea\x00\xb4Ki\xda\xf4\x1a\x1b&\xcf\x90\x17\x14\\f\xe8\xb5y\x7f\xcd1|\xccyl(*m8*\x06jA\xea\xc1\xbf\x07\x10\xe8\r\xc3\x90\x8d\xf8\xed\xfc\xdf\xbd\xbb\xcd!^lh\xael\x17\xadz'
        b'\xb6`\x0by\x10# \x0e\x03S\xb03\x02\x7f\n\xecK^\xefP\xfd\xbd\xc6%\xb3G\x89\xb8\xbf\x8fkE\x81\xb3\x17G\xb3&8\x11\xc2\xa6\xe9\xa7\x991\x81^\xa0V\xff\x904(An\x86\xae\xe0\xc0\xa8\xef\x89\xdb'
        b'\xe45\xd6\xc6\x89\x00\x83{\xae~\xd1\x9d\xcd-K\x9a\xa9\x848\xddt\xa3q\xeb\xf0g\x08\xca\x97\x16\xc6\xb8wJ\xb8\x9b\xfb\xc8\xda\xd4\xdcs\xe5\x00\x19G\x80\x12U\x11\x82B\xd4_>\xb1\x0bPjM\xb3r\xd8\x80'
        b'/y\x83\xc7\x1f\xdb\xb4,\xf7G\xcb\xe0f\x8dv\xa5\xe2^n\xaf\xd9\x9e\tK*6G\x9635\x19uP\xf5d\xc8*^\xce\x97\xef\xa4\x97r\xf9\x01\xffS\x81\x98\x16P\xe5@\xc2\x16\x94\x19RA:e\xb0%'
        b"v\xa1m\xc6ULP\x1a4\x1a\x88\xb4\xc2\xaf\xdb\xbc\xdd'\xdb\xff\x99\xac\xfc\xcbG\xe3m\xb5i\xfe\x10<\xf4@\x8c\x02W\xab\xfd\xc6\x06#\xb3\xfa\xc6S\xa4Yj\xa1\xf1\xab\xea\xa8\x90\t\xba\xb7K\x00~\xb9#\xe2"
        b'\rA|\xb3\x178V\xd3\x1e\xbbu\xb7w\xb5d{\x01\xce{\xf1\xf4\xfd\x06\xe1\x11\x10\xe4{\xb0-\xd8\x10]:\xb6&\xa4\xcd#\xc3\xf9\xdd\xca\x8e E\xe8LS\xd15\xfc\xd5\x03\x92\x18\x0f9\x9a\x8dcK\xe5w'
        b'\xe7)\x19\x10cr$G\x13\xc7\xff\xbe\xfdOD\xd6\x84\x89\x144et#\xa2\xf2q\xfd\x88\xa4z\xfd\xa7RD\x1e\xa4\xf7\xe0S\xbd\x9d\n\xd7\xdd\xd9\xd7\xe3\xa7!\xdb\xa9\xb0\xa4&\xcc3\x1a\x9d\xe1S\xd1\xa8\xc7X'
        b'\xf5\x0br\x01\x13\xeawo\xc8F!\x06\xce\x03,\xf5\xae\x01\xbf\xcb\x9e\xb2\xa9\n\x0e\xf1\xae\xeek\xcfi\x9dl\'.\x9f\x7f\xady\xd5\xd86)\xcf3\xa8\xefT\xbcB\xce\xc9\x9d\x81\x94\xccB\x1a\x17\xa6]"\x96\xa5'
        b'\xaf\x93(\x82\xae\x8b\x90\\\x8fy"\x9a(\xbe\xba\xbdw\xa4G`wm}+\x13N\xaf\xab\x85\xd2\x15~\xf3\xf5\xf2\xf4#\x1f\xd4P\xaa\xbem\xba\xdc\x03W[\xbad\xb4\xc7\x07;\x870r\xec\x8f\x0c,\x7f?\x8a'
        b'\xa2\t\\y\x8d\xf5\x19\\\xf0\x93>L\x96\x89X\x97\xa7\xff\x9c\x84\x03\x02/_\x8cs\x90\x82\x94`\xb0\xdcI\x19\x8epc\xba|\xb4\x11\t\xb4F\xc7\xda\x85\xb2C\xc3VV\x08_<\xaa\x82\xda\x89-s#=\xa7'
        b'\xd6\xef\xbc\xbbg|Q\xbcFR\xa4\x03\xfd\xd0fr\xeeW\x96I\x18\xeb\x8b\xb7,P\xab\x83\xf4\xbd\xd9q\x1d\xb6\x1eV\x13B\xc6\xee\xedA\xc4Z[\x1f\xfbj\x94\x1e\x12\x90\xaf7\x95\x1d\xf7.O.\xd8\xb5`\xa9'
        b'\xb7(\xda"\xeez\x94\xb9\x000jMI\x1d\x89\x80\xa3N\x13\xa8NU\x9cj\x18\xe7 \xa8+G5\xd9p\xb3g-\xbc\x06\x13\rG\xe3\xc9k6\xaaG\xda\xd6\x0c\xb5\xc7\x18b\x91l\x85AC\x14\x04n\x99\t'
        b'sV\x8f\xe5,\xed\x9c\xc1\xc8(\x80y\x85IW8y*\xa2\x7f\xe1/\x8b9\x840\xfb8\xbd\xdb(\xb6;\x08\xd4c\x10A\xae(\xe9t d\xad\xd7\x94fv`\xdb\x04*\x9c\xadt\x0e\x879tA\xe2\x13\xeb'
        b'wI \xf8\x04t\x9ep\xf8\xd8O\xe0\x9c\xc3\xd6\xfdR\x10\x87\x8e\xe8\x01\x17.\x12+:\xd2\x82V\x12\xe0\xcc1\xef\x1b1\xdf\xefKY\x84\x0fkU\xe1,\x82)<e\xc9I\xfe\x96\xaev\xdfo\xf0\x8a\x97\xea\x80'
        b'_\xa6uO\x8a`P\x0c\x06"#\\#\xb8t,e\xa3di\xcc\x18\xa2\x1d*\xcb\xab\'=\xeb\x8b\xf2\xcf\xaa\x8f\xe5"\xee\x8f\tw\xed\x16\x1a\xa8r\x9b\x90\x9d~\x8e\x1eiz%\x81\xb0\x87\xea\xfa\x9e\xc15M'
        b'\xfcL\xf1\x84\xb9\xa72\xbd\xf9)qp\x10\xc4a\xd2\xc1\xf1\xc6\xa5O\xe6\x14\xe1{/\x8a\xc7\xa5\xd5b`\t\xd3\x17\xf4;\xce>\xc9\xdf\xac\x04\x9a\x8ah\xb6\x83\xbb\xc2\x8b\xdaKEGA\x15\xc9\x14\xd1>0S%'
        b's\xa7\x0c\xa5\x90Wa\xd9Zs\x8a\x9f\xcd\xb63\xc3\xc9\xf5\xe1\x8a\x89\x9dmv\xea\xc5\xf8\x01\xa9a\x86\xd2S\x86\x96>\xed\x8e-\x15#W\x7f\x902z\xa1Nz^\xb0\xc32\xedL\x0f/u\xb7\xcbN\x94\xa8\x0f'
        b'x!\xabf5\x83\x13\xc1\x948\x84E\xd10\xdb@\xab\xd1\xdbUj\x04.\xe1\xe1.\xe2\x13\xfc"\x01\x9e\xb1\xc3\xd1\xd1`c\x98b0Q\xa8\xfaa+\xcd\xa1\xefW\xcf\xd8\x07P?J\x16\xea\xf7\xf0\x9a\xd0\xd1\x1f'
        b'\xe3\xcc\xfa\xd4S\xb3H\xe3\xa7\xb1\xb3\xa6\xdcE\x8b\x07\xfc\x9eM\x1d\x978\x8c-\xf5\xc0\xb9\xe3\r[\xe3Cr@TZ\x0e\xe1\xfe\xf0\xca\xe6\xa9\x1a\x03\x1a\xfa@\x18\xb8\x80\\\xc1\xf5V\x07\xc3\xa2k+gx\xbe\xdd'
        b"\xae\x08\xd752\xc5R\xc5H\xd4c\xbb<IZ?\x01'*\xcd\xc74\xa0h&&\x80\xd5\xd2\x1f\\\x8ey\xce\xbf\xbd5\xf9+{W\x1c\x9c\xab\xe9\x97A\xa7X\xb3\x06\xe3\xdc\xd9^x-\x80?\xb0\xe5\x07#\x90"
        b'\xccL\x82\x18;>~|\x17DBZ\x90e\xc1\xbbk\xa2\xc7\t\xaes\x1d?z\x91\x15\xec\x96l(\xf3\xd7\xb5@\xec\xaa?\\\xf8+\xaa\x86\xe8\xe0P\x95\xff.\xda>n\xba\x7f\xacJq}b\xd9v\xa9}6'
        b"\x91\xfeo\xba79\x18`9\xe4\xcdgX]\xafs,\xa0\x05\xe4\x11\xe2\xfe&m[ T\xccK\xf0\x10\x07\xb8\xce``\xf6\x96\x19\xcb\xc7\xac\xc3=\x00\xa2\x96s\xc3\xf8\x1b\xd2\xa7\xbe\xa6H\xe6\xb8d'\xe7\x0bU"
        b'[\xa1)\xd8\x84\xfc\x7f/\x99\xb1\xed\xf4\x1c\xe7n\xfb\xf5"\xb1\xf05\x92[\xbb\xf0Z\xef\xfd\x0c\x96\x15\xdc_vo\xa4A\xca\x9aY$\x9b\xc1\x03\xc4t\xd8\xe2\xec+v\xf9\xfb\xb54\xadp\xa4{K\xcb\xa9~s'
        b'\xda\x19F|\x1e\x8c\xd6\xab\xc6\xb6\x9c\x05>o\x0cy\x03\xd6E\x05\xa8\xc7bQ\xe75\xb4\x9a.G\xc3\xfe=i\xc4\x9e \xe9\x8a\x0bAM\xfb\xa9\xbc\x8bmi\xac\xa7<\xa8\x91\xf4\xba\x15G\xde\xad\xd6\xe1\xc4v\xd5'
        b"@2I\\\r\xc9\xa7\x92\x8b_\xc1i'\x8c\xdaS\xd1[\x9b\xa4mW\x07\xb2\xce\xcb9Z\x1e\xc7\xfdS{y96\xbf\x0cgq\xed^R\x08GRjL0_\xb9 5!~e\xf9M\xba\xe05\x1c\x15\xab"
        b'\x981\xe8\xa5\xaf\xa2M\x01\x0b\xffb\x9c\xc9p\xdc\r\x91J\x9b~\x86\xab>\n9\xb9\x91\xeb\xfeP\xe1\xa7\xe0\xa4\x86\t\x06o]\x8ae(\xaa\x90\xdd\xac\xe5\xccR\x94\x0b\xcd\xa4\xcf\xffx\x9e\xcb)\xfe\xb9IK8'
        b'G\x98\x05g\xac ;\x10\xb7\x1890uX\x8b\t\xf1\xfe\xbfl@\xfc\xeb\x07!\x8c\x82\xbc\xdc\x82\x9d\xe0\xd9:\xf8\xab\x1e\xbd\xb6\xb37\xb4&\xc4\xea3\xb1\xc3\x94\xc6Y\xf1C\xf2<\xe5\x02\x85\x17\xd4\xcd\xc9h\xbb'
        b'u\xb3\xd2\xc5\xf4\x90(6+\x1fa[\xb9\x07l,\r\xf5|y,\x97\x02\xb8\xbd\x00_\xefQ\xb7\xf7\xe6V\x98\x0c3\x94)\xdav\xcdg\x8fN\xfc\xe1\x92\x18\x9e*\xdd\x1cm\xcd\xa8\x10lk\xb8E\x8e+\xcc\x0e'
        b'\x15S\xff^Wq\xa6\xdd\xa2L\xceT\x0eT\xb0\xbe~\x97\xbb\xbfRD\x89{\xc6oF\xe6<\x9cb\x15Q**=\x1b[N\xdfR\n2[\xc5\xa6\xa3\xacZ&\x17[\x88\x96G\xc65\x8cU\xd4Ot(D'
        b'\x92\xc4\x06\x01\\%\xa8sS\xfa\x9a\xba\x8dc\xf5z\xf6\xdc\x16(\x15\x8dY\xca\x90\xbf\xa6\xda\x19\xc4\xf9,1i\xbeR\xa2\xdb\xc2A\xdd\x1fa\xef\x83LT\xe5C\x8e\x11\xd1\x13\x18\xcb\xd3w\x01\xd3\xef\xbe\x83\xb3\x94'
        b"y\x0c\xd6%n\xd2#\x9f\xa6\xe4\xc0\xd5\xb7\xa39\x8d\xefn\xb2\x0eE\xc8-\xaa\x8e\x1e\x17'\x03\x94\xb5\xc8\xbf\x05\x91\xee\x9c\x8a#\x03Q]<\xcd'\xdc\x8e\xc9\x9a\xc5hv\x9d\xbbn~\x93\xe6L\xbb\xc5i\x95\x8b"
        b'\xb8\xcak\xe8A\x83\x15\xb18\x13\xbf\x16\xf4\xab+\xa3\x05\x94\xb89xM\x8b\xd6L<\xb2\xfb\x1d,\x15\xfb\x84u\xcc~\xf5\xcf\xf3E*\xfa\xd9E\x87[\x12,\xb9\x8eoP\xff\xb3\x91\xeb\xcd\xbf2\xba\x10\x0f\xe8\xd7'
        b'=\x06\x9a\x1d_F\xde\x83\xa9\x18\xce\xde[ywn\xcd\xd9Mh\x93\x163VX\x82\x0b=\x1c\xbcK\x06\xe5\x89\x9d3l\xaa\x04\xc9\xf3]\x05\x10tB\t\xdfvP\xdf\x94\xde\xff\xed\x11\x97\xc0\xc3\xb5"yc\x8e'
        b'}\xf1x\xe0\xc9H\x94\x93\xd0\xa0\x8d\xd7\xb1\x9c\xc2\xcf.\nNh;\x97\n\xcd\xf4\xc5z*\xa1\x8c\xd0\xdf\xc2\x81\x17\xfe<w\x04\xd1.@<\x1a\xe7\xf6[te\x8bZ 12\x07\x8d\x93\xc1\xeb\xb0\x02)\xcf\x9e'
        b'\xee\xde\xc3ul\xfb\x12\xc4\xce\n\xbb\x97?\xc1\\\xea\x8bF\xbe\xde\x19\xc9&\xed\x88A\xe6\xd1\x85\x85\xe9\xa7\xe7\x8ct\xda\x80\tg\xd4\x82\x0e\xe4\x0b\xc3\xa2\xe6Q\xf3\xf7\x85\xc4\xaf\xc3C\xb1\x1b\xb4\x98%\xab\x8a\xf6\x8d'
        b'\x1b\x9b\xb2\xd0\tP\xb8\xb8]\x07v\xd2\x88_Fw\xb9\xa3\xcao\x87\x82\x11\x06\xaf=\xad\n K\x04Y\x94\xab\xde\xe5\xcc\x95"xQ\xbc\x85\x07\xac\x94\xe0\x91vd\x10T\x13\xb9\xee\xf04\xea\x957\xa3\x9b\x19\n'
        b'\x10\x8a\xc9\x85@\x19\xc5s\xd7#P\xddSS\x1f\xf3\x96\xf9\xa8\xb1\xd6\xd3Q\xa8\x10\xf9-\x05\x84\xd5\xec\x07\xbe\x9a\xfd\x8e``l\xbd\n\x82)b\x8e\x02\xca\xdf\xa7\x08D\x0e\xe6\xbc\x07\xea3\x9a,\x883\xe3\xfb3'
        b'\xc57\xcec`N(w\xc8\xb0!#y\t\xcf\xecq?\xaf\x91n\xd5\xdc\xc6\xe02co\xb0\xba{\x9f\xdbEfL\x08G\xbc\xeb_\xe7\xca\xd5\x08;\x91\xfaHq\x10\x8b7\xa4\xc1\xdb\xd3\x98\xc7\xee\xfd\xf0\xe1m'
        b'\x9f\x97\xe9\xf9<a\x1a\x7fD\x03\xbf\xef0m\xb8e^D\x9e\x04\xfe\xae\xc8E;\xec\xa26\xad\xbc\xa1\xdf\xfe\xf1\xed\xcbn\x94\xff\x8e\x1cJ\xa0z\x8e\x99\xe4\xec\xf6c\xdeCYq\x01\xce\xa3\x1eYU?.\x02\xb8'
        b'\r\xe0\x85\x17?;\x80\x19\x14\n`x\xdd\xff\xe4\x19\xc0\xa65\x16\x84\xe8\x8b|\xfa\x92\xa5\xb2\xaf\xa2x\x07\x8dLa\x19\xf3Q\xdc\xd5\n\xf8\x1c\xaf\x0cT\x9c\xe5\xe9\xce\xb5\x9dM\x1bK\x07\x0e\x02\x8f\t\xb1\xf7\\\x93'
        b'\xa5_\x04\x08*\x96\xcbC2\xb6c\xb7cP<?\xb3:\x8f\x99`\xda2\xcf\x94?\x93aEu\xf7N\xb9v\x83\x00\nY.\xb5=\xb7B\x04\x93<\xf6\x95\xb1h\x1b\xc47\x16\x1eWM/\x8ba\xadMf>'
        b'\xdb\xa7\xbd\xf2\xec\x16\xb2\xd1\xafrDM|\xe4b\xff\xd28\x9fD\x84\x1b\x08\xa4\xb9\x89\xbf\x1c\xda\xa6\x84t\xb9\xe5\xcc\x18j\xa7W\x9e\xd2\x82\xc7\t;e\x97\x92\xab\xf6\xd6U\x13\x04N\x0ew]\xd1\x95\xb2\xe4\x88C'
        b'\x83\xce\xfbt\xe5fY3\xa1\xa6\x0er7\xb9T\x0ek\x04\x9cX\x0f\x95\x8d\xf4.{\xceLhPo\xc9\x0f\xf0\xe2E\x1a\x9a$\x9d\xe8\xf0\xf7\xf3\xfc8\xe4\x07\x07\x94m\xac\xfb\xd9\xe3\x9f3N\n\xb7\xf9\xa6\xbe\x1d'
        b'?\xb6\xb9v}\x1bT\xfb\xfc$\xbf\xff\x0b\x9eD\xf11v\xd4M\xc6\x97y\xec\xeeV\x1a\xf6O6\xc0\x11>7\xdao\xd5\x9e4\xf3\xec\x05=\t[\xbd\xdf\x10\x83\x9e\xfd%\x91W \x0c\x83fb\xc7(\x17\x8cF'
        b'6\x9c\xeaS\xcf\xc5\x0ei\xdc,`*\x01\xc7\xb3/}\xb8X"uz\xe6\xfb\x1e\xeedB\xac\x90\xe1@\x0f\xe1\xda\xccL\xdf\\\x02\x95\x81\xbd\xfdI\x95]L\xe5\xf7c**U\x90\x01\xd2_\x8c=\x95\x9c\x99t'
        b'\xff\xfa}H\x15i\xd9qTBw\xc4\x12:\x05\x86\x10O\xa31M\xf2\xde\xef\x14o\xfe4I\xeb\xd9\xea\x12j.\xabC\xfd\xeb\xda\xf2U\xc0 k\x96\xd6/\xe6\xb6\xae\xd0\x07\xc7\xeeL\x84d;("\xdb\x01m'
        b'\xa9\xe8\xcf\xcd%\x92V\xd4\x8e\xef\xc4\x19\xaas\x11\x91SvIs\xc9z\xdbJ\x87\xfa\xb4\xd6$\x98+Z\xd9"\x97\xf7M\xf2\xc0\xcd\xaa\xc2\x0e\x84[\xc5\xf5A\\\x8a\xd6\xfd\xb3\xe6\xd6\xdb\xd5\xb7_\x08\xd8\xf6\xfd\xb9'
        b'\xe3\xde\xae\xdd\x8a\x1e\xf2?+\xbbz8\xc2\xbay\xc9\xec\x9d\xf8q~-\xf9:\xd1V\xbc^j.\x8c\xcb_\xb1\xfdO\x80\xaf\xfc\x1d\xf3\xc8\xaf4\xf5\xc8\xd2\xc4>\xe8\x00\x8d\xc8\x84\xed\xfd\x10Dol\xd6\xf0Pj'
        b'y\xf3Q\xc6\xcc\xf4D6\x92\xbc\x9eo~\x02\xb5\xb6\x16d\xae\xaf\x93\xb0\xcah\xd8O\xf9I\xeb\x7f\x05\x8fQ\xaaN\xac\xa5&\x92>\xf8h\xb4\xf9\x06]v\xfe\xe3\xa3:\x11IT#\xed\xd3,\x90\xa0\xbf%\xc3\x01'
        b'\xfa\xf3\xead\xe4V]\xbc\x02\x8cJ}\x10]\xa0\x9f\xb2\x08$\xfd\x1ah\xe4\x1cg\xbf\xa8V\xb9\x0c\xbap\x05\xd8\xf7\x184F\xfa3\x9e\x85\x8em\x85\xecRfnq\xe8\xb4\xdaEd\xbe\xf0\xa5C\xe2a\xe9M3'
        b'\xd9\x80\xb1\xe6DG\x19\xc6\xa6j\xec\xc5\xc4\xee\x1a\xf0\\\xe9\x87\xd8E\x80#\xe3\xd8a\x88\x92\x05\xeauu\xa9\xec\xe6\x83\xbaH\x11\xa4\x0b\xab_\xc7\x89\x89}\xd8u\x034\xc7*V$O\xdd\x07\x1a8\x9c\xd6\xac\x17'
        b'\xd8\xe2]k\xdd\x88\xdf\xb6lM\x00\xeb1\x8d\xa2Ok=\xbdV\x96\x88\x04\x08\xcd\x9f\x93\xcd.\xdap$\x97[\x1ec\xf6y\xd1\xfa\xe0\xd7\xd5U\x95\xb2\xd7\xb3\x96\xd6\x9eC<\xff%\xdb\x811^\xa2\xf0w,\xe8'
        b"\xf9\xa5{\x9e\x01\xefd\x9e\x02#\xd4-w\xe2\xcc2{!\xd9)\xe8\r\xd8\xa5\xe6.'\xf969z\xc3\xb9\x06XSj\xec/\x85mL\x01t\xcf\xe3\xc0 \xba\xcfm\x82&\x1e\r\xfdq\xdf\x98\x1d\xb4\x1aS4"
        b'\xc6"T\x89\xf7\xb9\xb2\'(6B\xdcb\r\x85\xdb\xd09\x0bF?\xf1\x81L\xf2:85\x9d\xe3\xd2\xe4U\xcdG4f\x18\x0b\xb9B\xabc/\xdc\xc0\xfa\x8d\xb8A\x12\xac\xd93o\xfe\xc3\xb6O\x8d\xbe\t^\x8a'
        b'\xe6\x08\t\x1d\xdb\x8d\xa0\xcf\xd0Yb1\xe9\xa0\x8f\xbcG5\x8d,\xe1\xe0\xe6\x07\xf6}\x88\n\x9b{\x98k+\xeaOV\xef\x83H\x0f\x05\x11\x18|\xe0\x15\xdfV\xd67j\xab\xf7\x0f\xc6\xe9:\\\x94Y_Qx\x95'
        b"\x83\xab]f\x9e\xceAf\xc0TW\xffN\xd0\xf3Y\x02\xb9\x16\x84s\xa5\xf9\xb1\x97\x85\xf1\xca\xef\xecu<3Jtj.%Q\xda\x08\x8a\\\xf6+\x91\x9e\xe6\xab/\xf0\xc4\xa7ZU\xba\x9f\xf3\xe7\xa34\xcd\x1f'"
        b'\x88\xc8B\r\xb0FR\xf3\xa9\x8b\xad\xbcY\xb3\xbai-\xf8i+j\x97\xa0\x9bL\x13\x97\xc5<\xfc\x9b\xed\xf7\x19\xc1\xb9Dd\xf2VS\xe9J\xfc\xc3.\xdd\xb9\xc5\xa6\x98\x0f\xf1g/\x8b^\xf6\x96\xb4\xd3\xca\x9e\x82'
        b'P\xe6\xd9l\x88\x19\xf3\\\x1ex\xdbQ\x7f\xba.\n\xa0F\x91\x97Tf\xe4\xde\xcb\r{\x9f\xba\xb9A\x18\xa2\xe6\xc5\xa1R\xb2W\xadA\xa2\x1a\xf5\xc4\xc0J\x01V\x9b?\x8b&\x91\xf1\x1c\x04\x11\xf6\xf4sGV{'
        b"RY\x94\xc2\xdf\xcc7\xb72'\xe9\xb0\xdc\xf7HtM\x1cet-1\xc8\xb1\x80m\x84\xd7);1\x14\xe2$4\x1b`\xd3\x99\xb0\xda`\x03\xe9\x00\x10{\xe9\xdeBL\x14\xb4\xa5\x1e=\x9d\xbd\xd0]\xdbZ\x128"
        b'8\x9c5\x86p\xa5(5d\x1c;\xe0\xca\x94%\xf01\xbc\xfd<\x1f\x08?{@]\xb8\xccN\xfb!\xaf\x05h0\xc0\xe2\xd3\x9bj \x81\xbb%vj\xe3\x01.1\xfa$\xd5\xef\x11\x1f`zT\x83\x9bA\xb7\xed'
        b'@\x90\xe4\xce\x8b\x94\xd3\xeb\x97\xbe\x92\xfe8(\xeca\x92\x1a\xdc7\xfa\xc3I\xc0\xaa\xb7}s!t\x8f\xb7\x06\xf6\x0b8\x86\xae\xa5av\xddN(\x9b\xd3\x1d\xc3\x00\x9a\xa0\xc3W\xbc%\xc0\x87U\x8c\x14\xee\x83.\x92'
        b'(e\xe0!\x0e1|8\x7f<>b\xc18 \xb1\x9a\x9c\x18\xc34"\x05\xaa\xba\xc0\xccQ_\x83\xa4\xf1\xacB\xf4B\xec\x07\x8f}\xe2#\xd7h\x9f\xe5\xcaT\x86\xfb\xadu-\x0c[\x9a\x01:\xc5\xd2\xb3\xfa\'3'
        b'\x1e()\xba\x84_q$ [\x0fJ]M\xe1\x97\x18\x1a0K\xeb;\xd3$\x1b\x8f\xb9\x15\xff\x16\x9cQ\xf5O\xfa\x8c\xc6b\xbap\x97\x13D\x17=\x95d:\x1e\xf9\x1b\xcae\x00E\xd3)\x83\xb3\xc31$n\x8f'
        b'\xab1QUm\x1f\xe0\xf9X#\xc8bF$\x89\xef&M\xaaU\xcb\xed&\x11\xc7\xf0\x945\x1e\x9a\xd65\xa8\xc5c\xdbo\x10\xdf^\x82/\xdb\x07\xd9\xc1g\x8f\xb0\x99\x12&\xe5\x87;\xe3\x01\xd5\xaer\xaaz\xd9\xf2'
        b'"\x13+J\xb8\xed\x96rZ\xbe\x95&\xd0=~\xcf#\xf9)\n\xf1\x0f\x10\r!A\xd5F\x14\xc9\x00\x1aP\xb0\'pXI\xb0\x99\xe1\xf7=)\x9f\xca.\xe3m\x83~3S2[Sd\xd4l<2\x85\xb7X'
        b'\xb2\xcc\xbfk\xe9\xac\x11sF\xa4M\x16\x04\xae\xdf\xa1\xc6\xe7t/\xfb\x17Y9\xb7C"\xdaL\xae\x91\xef\r\xc2h\x8c\xd8\r\x19_\x9b^3\xb6\x89\xea\xad\x17\x1cE\xfbQ\x0fu\x874\xb7\x16\xf9\xa0Bs<\xd1'
        b"\xa3\xb5\xbb1\r\xe4C\xdaK\xedM\x97^sn\xb3\xc5\xedE\xfbn\xf1PX\xcd\x94T<9\xd9\r\x1c\xfa\xc4\xdf\x94\x07\x1a$\xdb\xdd\xea\x98q>\x14'\xeb\x906\xadx\xd2b\xdf\x9f&5P\xa9kJs("
        b'\x02\x15j\xd3J]\x88\xecs\x13\x17v\x8f\xdf\xe6\xca\xb8\xa8h\xad\x14\xe8\xcf\xedZ\xd0\xb1\x9b\x1b\xce\xc9\x90\xca\xcd\xea*\xe7\xc9\xb2\xd8\x9eo \xa4\xda\xff\xaf\xa4g\xdb\x14\xcfI\xab\x11\x1a\xd7\xd48Ag\x07@x'
        b'`\xee\xde\xc6"T\x18=\x85\x7f1\xc3\x1d\x12\xaa\x80\x8dA[\x0fjhF\xcc10\x80\x8b\x12\xb5\xe5w\x8a\'\xef\x81;\x9b(R%\x08\xbbqJN\xb9\\_~3SV\xb5T~\x1cE\xf7\xaf\xbb0/\x13'
        b'Q\xfd\x1a\xcb\xe0\x8d\xa6\xaf=\x9b\x1c\x07\'r\xaa=G\x02\xc7,\xc5Ix\x89\xbe\xf1&\xef\xf8V\xc0\x08iw\xf4\xff,\xcd\xb0\xe9"d\xa3\x8d\xe1\xd1\xa4\x99\x0e\x93si\x18\xa7\x9a\x86y\x1a\xa3\xc0\xcbK\xdcj'
        b"\xb9\xe4 (\xb0'\x9a\x1a\xef\x90\xe6\x17\xbf\xe3_\xf6\x1c\r$\xf6\xf6\x13\xec\x93\xe7GhDO\xb7\x18'\xcf\xf3\x9f\xe1K5\xc8\x0e+l\x12E\x19O\x7f\xe2&\xbeo\xc8\xd6\x9e\xd2.\xbc\x8e c\x11\xa4\xb6\x00"
        b'\xce\xb2n#%H.2\xe4\x11`\x1c\xe3\x8b\x8b\x82T\xe7\xb1Q\xcd\xa2r~\r\xf0\t\xb7\xf8\xd2r0\x16\x08\x94\xe6\xca\xd4\xb2\xe4:\xa6Z\x1f\xe6\x8c=\xff\xed\xe9\x9dH\x00\x95zU\x06\xfa\xe5d\x81\x03@\x9a'
        b'\xea\xd5\x1a\xdd\x0b.SI,bg\x87\xd5\x94=,\x8d5\xea\xd6\xc2c\x97\xca\x17\xe78B\xf3a\x04\x1e\xcf\x10Q\xd7K\xa8dA$\xa5\xb5\xfc\x9a\xb8\xa3\xcf\xc07\x8a\x08\x95\xe7\xc9\xe3\x8d\xbc\xf7\xa6\xc8a#\xcd'
        b'\x02\xd6\x17y\xac\xe0\x91\x06DOh\x1a1I\xa6\xb7\xd8\x9aT<\x9e\x06,\xd4P\xefl\x96\x93\x1bg\xb0\x18Kv\x07~@\xff\xe8\xe0\xb1\x0c\xad\xaa\xcb\xbeP\x9e\xfb=\x11\x05\x18G\x14\xd4\xff{\x89\xc2W\x00\xa6'
        b'\xddX\xdd\xe3Z{\xe9`\x7fAv\xd3\xfa\xdb\nH\xf9<\xe5\xca\xdd\x8a\xea-\xd7\x87\xd7D+\xbb=\xec\x14\x91\x06\xd7\xe4\x0e\x85\x0b\xad\x0e(C\xd5\xec\x9e\xbf\x1e\x1b\x1c\x8f\xa8\x87~U\xd8r\x9c\xb8VD|\xc7'
        b'r\x85\xee@s\x9c\x02{\x08]g\x1e\x0bH\xa5[3\x08\r\x10r7)\xd7\x0e\x06\x92\xbe\x18\x83\x94@\x86-\xeb\xf9\x04 R\x8b\xb7\xc2y\x83\x17\xf98\xeb\xa3\xa6b\xd1c\x7f\x90K\xe4S\x00\x1b;\x05\x0b\x92'
        b'\x81H\xf5\xcb\xae\x8a\x80c\xff\x9a\x82&\x1f\xedg\xa6?P \xf7\x0fr\xa1\xea\x8a\xb2\xac\xa3\xed\xd9x\x0e\xe5\xb3L\xa0y\xa9\x8b5\x1fL\xbd\xe5\x0f\xb8\xed[\x16x\xdd\xbcPsK\xbe25D@\x9e\xba\xfb\xc7'
        b'/\xe1\x86\xee\xf6zsQ\t\xd7\xf3j\x9f;\x9b\x1d\n\xd4F\xf5\xc5\x8f\xe9i{Iw\xfd\x19\xb0Y{C?Sg\x86\xfc^u\x96[\x8b\xd0&\xb5U%b\xcc\xad\x08l~\x14\x9b[\r\xc2\x01\xc0\xed\xf5\x1f'
        b'\x92y\xc9X\xdd5&7\x1f\xef\xb8l\xc4y\xed\xb5}\xc3\xaf\x99 \xc9\x85\xc5\x92\xdf\xab0\x8d3\xa6\x84Q^\xb7A\xc7\x06\xad\x86n\xee\xb5\x9a\xddHl%nl\xec\x12g\xec\x06h/\xc3W\x88\x976Jo'
        b'\xf3\x11&\x80\x88\x06y\xff\x81\xb0\xbf4\xd2\xc3\xb2\xea,\x97\x86\xa5\xaa\xbd\x85\\\x842\xf8_\xa6\xad\x9a\xe4\x9c\x8cK\xab\xc6\x95\xc3\xa5\xa6\xef\x16d!\x9a`\xa8YF\x02\xc2qR\x1f\x97\xd5\x87\xd1\xd7\xeb\x82@\xea'
        b'):,\x03[\t\xd0\xe4cD\x1d\xaa\x8a\xa3\xabn\xaf\x93Q\xeb\xfa\x93\xc1\xaau\x1e\xf9\xd4\xd9\x1d\xa6\x00`\xd5\xb6\xf0\xed\xa6\xb3\xb0\xc3\xccC\xf2\x89\x93\x87"\r|\xf9\xfc\x7fS\xe4\x935t/\x87!&Y\x9b'
        b"\xbag-[\nB\x8e\x83\xde\x96J\xc8\x7f\xbe\xd02\xa7Y\xbf3\x81\\\xca\xe8S&\xff\xbd\x11\xb3\xd9\xad;\xe5?\xd7\xde\x8fH\x99\xa6\xbco\xed\xec['\xce\xfaz,\x03\x98\xadM\xfa%#\xec\xe9SI\xf7N"
        b'g\xe3\x10;\x86\xc0\xf9\x0eZ\xc0m\x00\xc8\xec:\xaf\x11\xed52%\xa7\xa2\xe6\x1b\x86l\x7f{\xfai\xb9\x04\x96\x9b\xa9b\xc6\x1aq\xae\xc3\xe3\x83\xd5uZ\xf8(\xf2\xf8/\x91U\xa5\xce\x00y\xa2\xbf\xfa\x02\xe1\xe2'
        b'W\xda\xb7\xe8K\x148\x16\xf3\xc2l\x05\xf6\x01t\x96\x93\x14\xe7s\x11\x82\xfb\x89\xc0\xd7\xef\xf1\xb1\xca1\x90R\xad\x88\x032\xcf!\x7fa\x95\x1e\xe1\x05j\xce\x84\xe1?\xa4Q\xbfT\x07\xcc\x02\x84\x9f4\n, \x87'
        b'\xe9\x0b\xca&\xe9\x06\xb2z]\xa9\xe4\xc9\xa9"?\xbe\xf5\xebH\xdb\xeb&G\x968\x10S\xb0\xe0h\xfa\x12?\xe1\x11wC@IG\xb0bG\xda?\x9fQ\xd7N\x03\x96k\x8b\xee$\x15\xf2\x02\xb7\xaf\x03DY\xac'
        b'D\x17.3#\xce\xe5M\xe3u\x88\xf9O&S\x01\xa7\xac4\x08Y$\xe0\xe7\xd8\x15%O\xd5\xcd\xe3\x8b\x05\xff\xbb\xae\x9dO\xb1\xa8\x93.(\x94\xdc\x88v\xbeZwy\\3\xdbZ/\x84\xe8\xbe\xd3\x00\xfe\xb3\x8e'
        b'/\xd0\x15eT\xdeU\xbf\x94\x15\xb4\x19\x12\x02!>\xa5\x95yg\xd8\x8a>}\x9f\x88D\xebV\xcc\xff\xc7Wo\xa6\xf9\xef\xe0\xf0>.t\xd2\x04\xf3\x93O\x0c\xdfZ\x8eN\xfc:` \xb4\n\x9cf\x1b\x1e\xfa '
        b'\xae:`m\xa9\xb9\xba\x1d\xb4\xd7\xe8\xb26\xa3\xa8\xfe\xe8\x87X`\x1dC\x1b\xd1\x9b#2\x1d\xf5\xfa!^6\xa7v"\x99\xc7-\xa6\xab?\x98(\xf2L5\x95u\xac\xb9\x15=\x939\x13u\xf9\xd0\'\xfe\\\n#'
        b'$b\xc0/\xa2\x87G\xf7\xf2\x12`s\xdf\x1f\x97J\xea\x13\x98\xb7l\x03J\x1a\xc8\xd7\x96\x8c\x12N\xf6\x85.\xdch\xf0\xdbs\xbf\xb5&\x8f\x87\xeb\x87t\xdf\x918\xe0\x8a\x1e\xed\xcfJJ\xef\xe7b\xed\xdd\x0b\x92\xbc'
        b'\xfeJ\xd8W\x14)\xd4\xa3\xff\x95\x00\xdaJsN\xd5\x17M\xe8\xf6T;\x86y\x8f]\xfd\x95\x13\x1dbLF\x9f_lK\xd0\x08\xa6\xe2K\xeeC\x16\x86!\x94\x10\xd9h/U<\x92I\xb9\xc6\x9d\x86\xd0\x15\xb2\x11'
        b'u\xe9\xfe\xac\x07V\x92r\x92L\xd3N9\xcc\x92a\xa71jYYp\xbeO\xccy\xd3\\]\xf2n] ?\x9c\x86\x8fOy5\xdff`\xba%I\xf5\r\xe5\xf8c\x08\xe6\t7\xfa \xe0wl\\\xa1fF'
        b'\x819\xa6%\x94\x85\xc7Ex\x0fz\xce\x9f\xb8\xcdw\xf7*\x7f\xd0\xe1\xc1\x987v~\xe9r\x80\x15Or\xba\xcf\xf62\x88\xafYq\xb16\xbc\x953\xa8\x96\x1c\x1d\xc4\x19\xa3\x07\xb9\x98N\x96\xb7\x8d^\x81\x99>\xa1'
        b"|1S\x18\x9b\x0f\r\x00\x9eN\x87GC\xe0\xe5AT2\x8e\xee\n\xbfd\xcc\x8e\x0fI\x06\x854\xe3p\xcd\x97\x85i-\xe0\xfd\x11\xae\x1d\xe19\xef\xfe\x98\x99\xd6\x94\xb8\xcd\x06q\xbe\xff\xc2'\xc4*\xcb\xea\x1d$"
        b'\xa1\xab\x8btu\xb0\xd3`\x8c\x9b\xa86h\xc8\xbeT\xa9\xefY\xdb`|\xfc\xedF\xf8\xcc8\xf7u\xd3\xf2Av\xce\x10\x98FO\x06~x\xbd\x08!\x96\x94\xfbbV\xfbY\xf1\\qV\xd2\xaa\xd8\xf8\xa5\xff\xe9\xd2'
        b'~%\xae\x8d\xdc\xbfI\xb4\x93\xa7\xa9\x8c\xb8G\xae4\xc6|\n:_\x82\x90\x93\x83\xba\x9ar\x19\xa8-[\xe5$\xf9\xd2\xff\xfc_u\x02\xa9\xbe\x17\xae3\xbaE!\xe8\xb2\xd2\xe8\xcd\xd5@\xd9\x13=O\xaf\x13\x12I'
        b'\xb5f\x92h\x8f\xa9\x05\x83\xad\xd2\x8d\xcd \x92\x16\xad\x05\xa8\xed\xd5E\x12#<6I\xe7H\xc3yS\xaa\xb1\x1f\x85\x1b\xc8"\xed\xfa\xe8\xdf\xd5\x98\x0bK.\xb7\x8e\xb4\x9a\xe4\xbc\x05\xbcK\xcd\x02\x06\x1b_wwQ'
        b'\xe0\x87?\x95X\xad}\xdcP#+nU\xb6\x1aY3}\xc0\xc3\xb2O#~o\xdaW\xa1C<&R",\x85\x89\xa3\xb2\x9b\x0f,&4,)*b9\x86~j%\x8e\xbc\xe4\xa7\xa0\x0fA\xd6\xdc\xc6\x8a\x7f'
        b'\xdf\xa1\x0br\xae\x84\xe0#\xd9c\x1a\xaf\xcf\r\xa7\x0b\n\x0c\x8e\xe7\xa00\xdbe\xa8|\xdd\xd0\xb9)\x14\xa4H\x9b\x7f\x15\xcf\xd9\xa2Nd\x15L\x87q\xbdl\xa8N\xf1\x16\n\x96\xf5e\xa9\x89\x0b\xe0a\xd6\x7f6\xd1'
        b'\x9f.\xd3\xfc\xff\x89\xdaMX\xff\x97`\x80 \x06Z\xc0\xf4\xf0\xf4&\xfa.\xb6\xd6\x1d\x9b\xfe5\xe5\x18O\x9c\xb5\xa1N)\xc6\xa7\xea_\xb5\xa5|\x85\xf3H\x1fbr\xdeCr\x05\xe7\x7f\\\xdf\xffT^\x9d\xfc\x17'
        b"RF\xac\x97\x0f\xdc\xef\xb6L\xb0\xc5l\x0f\xae\xcf\x80D7\ny\x89\x1c\xdb(R\x92\xc3n\xac\x958\x15\x8fq\xfaGee\xa8U\x83\x1fZ\x1c\xd3}\x86\xc6\x83\xd7\xd6 \xe0\xed\xccQ'!\x93 \x03\x0b\xc3\xcf"
        b'\xb4^7\x14\xd6R\xecw\x87WXe\xdf\xe5\x081lT\x9c\xfd|C\xc5\x865\xed\x1c\r\x91H\xa1\xf8\xeb\xb5\xb9\xa49\xcd\xa9\x05\xe6GQ!"T_\x85\xdbW\xc1\x07\x96\xf6\xa4\x99\x94u\xe7\x1fd9\xde\xa3'
        b'Bm&e\x9e%b>\xe2\xd8\x13\x91\xf4\xfb\xae\xf7\x91gp!\xc9p\xe12\xf6l\xc4X\xeeDI\xd4+\x19\x13)\n\x8f\xdb\xe6\x1f\xa0\x8dO\xfa5\xf4\xfb\x9ao\x98\xfb\xfa\x8d"=\xda\xa74\x12c\xe7o\x9d'
        b'>\xdbiae\x9fV\xde\x9a2?\xab\x12(\xce\x0cY\xc6h\x8ay6\xcdT\xc4dO\xef\xff\x1b^y\xd8=\x8bS\x06L\x056\xea\xe4\x94\t\xac\xd1\x7f\x9d\xa0\xd0d\x1b\x0ecR\xccv\xa5\xab\xe5\xb2Pzk'
        b'\xc92D\xc8\xa4\xbb\xd0\xb6S\x9e\xa6*k\x92\xea\xdc|sR\x07l\xaa-\xbd\xc0k\xf7\x1e\xb0\x16+ \x90\xa4\xba\xdb6J-\xe4\xf0=\x1c\xfb<!\xa0\xde\x86\xdf\xfd\xc7\x89\xbf[3\x92\x93b\x04b\x81\xb0\x0f'
        b'\x1c\x1b\xa3_\xf9\xbf"\xf5\xa8NW\xeb\x90\xeb3^\x08\xd0\xb2\xf8\xfev\xefH\xed$3\x07\x15\x04\x1a?\x14\xcex\x93nC:\xa2\x92\xea^\xa8\x11M\x8b\xb2\xd2\xa6g\x8e\x86\xbc\xf0\xf3@\xf3\x91\xb9I\x8d\xe3g'
        b'\xe8\n1\xcb\x96\xeb2\xb08\xbc\xbd\x91\xfd\\\xceu\xd1@P_\xd9g\r/Ei`\x86\x05Z\xce\x04KvxW\x84\xef\xd7r_\xef\xa6\xc8\x03g<\x89ua\xa5\x8cG!\x9c\xaa\x02\xdd*g-\xed\xb9\xe4'
        b'\x85V;\xf5\x9d\xdc\xae\n\x0cs\xec\x89QavD\x96\xce\xbd>k\x92rk\x88\x89\xfah\x97Gl\xd8t\xaat\x9f\x13\x11\xc5\xa6\xdd\xaa\x87\xaa\\V\xa8\xe9A\xd4\x97\xcf,\xb0]\xec\x96 \xa3b::Y{'
        b']\xac\xc4F<\xff\'\xecD\x91bM+)\xf55\xd7\xf4\x13y\r\xd2\xe6Sb\xed\x1d$G\xafJ\xbb\x84\x018f\xbe\xee*\xe3@\x14umD\x8f_"\xe8G\x8b\xb8p:N<\x1a\xc2\x06\xba9\x98\xc4\xde'
        b'<\xd0\x08\x02\xc5\x93\x1c\xba\xed\x1d\x85L@\x8a\xee\x8e`\xf9\xbf\xb7\x0cM\xa1\xe3\xf2\\\xa1a\xd8S\xc7)zY\xc3\x15\xf1\x1d\xd4AsZ\x91\xc4N\xff\x012\x889\xe5x\xbbD\xdd\xbep\x8dYi\xf4\x84!\xd7'
        b'l\xa8J\x1et\xdeN\xd0\x8c\xd8\xff\xa3\xfc\xb8\x1a\x12\x9c\x8c\x13\x93\xb3\x0b\x84\xe5\xff\xa9\xf4\x86~t\xd8\x07\xff-\xc4\x8eH\xcf*^\x06\xbb\xf7\x12`/%=&\xc2\x1cx\x17\xbb?=:\x8b\x98\xb6\xf4r\xb2\x80'
        b'{\x11~\xb1Wh\xc0\xa3\xc92\x8dsf\xc3\r\x83E\xe1\x92\xf2\xd4\xed\xae:\x87\xabI<\xaaF\xfd\xbf\xd5\xae\xa76:\xb4I)SY\xe3\xae\n*\x07\xc4\x8a\xf2\xa8M\x97\xa7\x19\xd8\xeb+V\xd38S\xe3&'
        b'd\xa0pf&\xe9a\xff\xdcV0\x93\xa6\x0c\x8d\xecj\xda}\x0cv\x87\x7f\x18\x01\xb9\xe1\xb8\x9a\xec;\x96\xebv\xd6\xea|6\xb2\xc5\xe1MG\x0c!\xbaF#Yg\xbfp\xe5\xc0S\xdd\x1a\r\x98\x82\xd5\xa8\xfa\xb5'
        b'\x8e\xb5NT\xc8\x9fT\xc1\xfe\xd41\xc0q\n\xedw\xccZ\x9a]\xa5,\x95\xf5\xd4\x0f05Tf\x85L\xd9\xe3J\x8d\x17v\xce\xa8\x87\xebH\xeb\xae\xa9rC\x9b3\xed\x93^\xad\xcc\x04\xd1J\xf3\x87y%HQ'
        b'I(N@\xac\xa0\xa0\xc6\xb1g\x08\xca\x8a\x82\xba\x13\\\xcf^DB\xbf\t\xc5y\x1c+X\xa6\xbd5*\'\xef\xe7\x94\x12p\x0c\xdf;"XU}\x92ms>IHH\xce\xf4\xed\xc7\xd0\x80\x15\x03QU"5'
        b'\xe4\x088\x0f\x8d6\x1cj\xb8zl\x1e\x98\xc1\xc3\xcas6\x021\xd8r\x96@\xa0\xaa\x85;\xc1\x1a"a\x0ef>cC\xed\xb2\x00\x13(QN\x1a@\x19\xcb\x17\x89\x86\xa5\xe1\xc8\xc13\xb4\x97\xa1m\x97\xb6\x85\xa3'
        b"\x0f\xce\xef\xb0\xa3\x139\x97\xc7\x83\x81\xb9r\x1e$9\x00\xef\x9b\x93%\xb8\x9c\x8b\xb6FW\xc4m\xf1f\x8c\xcb\x98\xc2l-'\xd4?\x85\xf2\x86O\x97\xe9w\xc9\xf0Z\xbd\xeeMR\x17\xcf\xc8\xb4\x80\xf8B\x05E\x9b"
        b'P\xe5\xc5,Y\xae\xdb\xfc\xbe\xa9\xc1\x91\xa3=\x9c\x0f.\xac,\x88\x1c\x0cj\x08\x92\x1a\xb4\xc4%\nK\xd0\t\xab\xb71\xf0\x03\xb6\x04\xa5\x81\xb6\xd5{X\xf4UBe\xfa\x82\xad\xb8\x01\xbf\xe5=({\x9aP4\xf5'
        b"\x81\xd0B\xaf\xfd1s\x15t\x087\xa6\xca\xbc'\xc9^z\xb1\x05\x1f\xd0\xfd+\x99\x07\xa0\xe0\xda\xd5\xfc\xaf/\xfb\xbfT\x17\xb47\xb9\xa0\xe6[\x87B\x04\xd4\xa1\xd93\xe6\x06\x1e\xcd%\x00\x8fk\xebjL\xa4\x08\xff"
        b"\xd6'\xdd]\xd4R\x06_A\x80q\xd8\xb2P-[\xbcE\xee\x96lj\xc6^\xba\xae3\xf5?f\xf9AY\xc0a\x7fpG%\x9aT\xbe\xd1Y\x18f4 \xa9\x85\x12\x06\x04NR\xd4E\xe6\xc3\x1c5\xbeR\x06"
        b"\xcb$\x9d\xc7\x11y\x02\xdaZ\xc2U\xa50\n\x91\x02\x88kf\x1c\x9c\x81\xaa\xfd\xa7W\xd1\xc2a3`n!\xa9\xea\x96a\xe2\x15\xc1]\x06\x92\xe4-\x84\x9a\xc2A\x00\xf8\xe7\x0b\xda\x95IE\xb1'H]\x07\x8c\x97"
        b'\x18\xbc\x8e\x16\x84\x0f\xfa\xa6d\x9dB\xe9C01\xe2<v\x94\x05U\x16h\x9e\xa35\x14\xa4\\\xd8\xe6\xf5\xa5\x96\xc7t~\xc0\xf3KW\xed\xc7\xc1\x90i\xbed\xed\xbd\x85=\xa6FD\x8fD\xf1O\xfd\xb9\xc5\xe0\x1d'
        b"\xbf\x87D\xda\x9cy\r\x97/\xa7R\xf6\xc9\x9al\x12q\xe4\x9d\xbf\x1cu\xc6\x0c\xcd\xadY\xe5\nQQ\xe8E\x03X\xb0\xe5\x8d\xdb\x12\xa9\x81\xc7'\x1ca#/P\x91b7m\xec\xf2\xe4\xe3\xf8\x97[V\x89\xf9\xaf"
        b"\xcc\x07W\xfa\xc6:B\x87\xc4\xd5\xad\xe3\x94'ev\xda\xb6@\x0e\r\xd3\xf7\xe5\xce\x0f\xbe\x951\xdd\xf9\x9d\x1c\x16\x038\x02\xbf\xa2\x0c\xb1\x1d\x9f\xe7w\x18\xfd\xb2\xee\xcd\xac$C\xe0i\x8cMlM\xdd45\x8bU"
        b'\xe0!\xb8\xf0a\x13\x1d\xb2y\xf6L\xdb\xd5 h\x195;\xcf\xe1\x0b\x8a6Ipy\x96\xd7\xb2\xbf\x89\x00\xc2\xde\xa8\xcb\x83\x9a#|\xfb\x0c\xa36\xf0\xe4\xc1\xc0f\x9c\x98\xfc\x8f\xc1b\x84\xeb\xa6\x07W\x90L\x92*'
        b"A\xb3I\x96&\r\xe6G\xfbW\xb6\xd3\x14\x11\x85\xfb\xb0_\xf7E\xe9m\xd5X\xe7_\xb8z\xd3\xc0\xad\xb4\xd6\x10\\p#\x96.C.\xbd\xcc\xe5\xd3My\x17R#\xf3\xb3\x19v\xe2\xfe\xb3\xb8\xc1\xe1'g1l"
        b'1\xde\xea\xb9\xfc\x19|y\x95\xf8\x0bsl\x17P/"=\x0e\xe5\x7f\xf6\x92fF\x90\xc9\xddBm\x8c\x02m\x9a\xf0\xaa\xf1k.\x87\xa7\xb0\xf6\x93W\x17\xb5tBc\xb1Zk2\x91\x06\xb88\xa1\xb0\xb7\x88\x15G'
        b'\xcf\xd5\x92Z\x96\xe8.\x98k\xd6\x02\xa7$4\xfc\xe5\xed\xa4U\xd0C\xed\xad\x94\x1a\xf4\xc5b(|P\xba\x8d\xa1Y\x91\xbcp^|\xbcF\xd5\x88\x8b\x13\xb9\x83\xaa\x87TM\xb1\x1aC\xece\xb9\xbc\x05\xc1_\x1e\x9f'
        b"]c\x14^Y(\xa1\xfc4O\xca\xae\xb9\x13\xc2=\xc5\x7f\x93g\xf19G8\xc3\xd4\xbd;\xa8\xfeo \xf1\x08\x93Dt\xa8\xeca\xbd\x01A\x15\xb3\x80\xf9v\x9d\xd0{'X8u$\xa5\xff\xa3\xc7&\xc4\xa05"
        b'\xf6\xfdGQ\xc7\xf6a\x01\x81\xd1\xa6\x8f\x86\x80\xc8f~-\xa56jh\xe7\xaf\x87\xf7\x87\xeb\xb4\x86\xc8n\xa5\xc1\xbb\x14\xe6p\x19b\x95\x16\xf9\xf9\xa5\xfc\xe1\xc8\xb8\xc6\x0bf\x1bt{$\x86\xe1\xd0\x13\x11H\x1b\x80'
        b"\x04C\xb8\x0e8\x0bK\xcaCL\x8a7\xec\xaa-NJh\xf9\x02\xde\xc8\x1eT\xcf\\(sS\xab\x0c\xf9\x12\xc1\xec>/\x81\xbeJDR\xbb6\xdcM%\xe4M9\xe7\xf1\xb6\xc1\x16\xd5\xa0K'h\xe9K\xd6\xb6"
        b'\x8e[\xf8\xf4"\x1c\xf7\xba\xadC\x1e\xa8dP\xe9\xbe\xde\x01\xf9\xf7\x8fd=#\xe2\x83\x8cB\xc6\x84\xa0\xb6\x01\xc9\xbb\x1a\xc5xc\xad4\x07fGh\xa96\rC\x18AUZ!\xa3\xdd\x89;\xb2\xb0,\xf5)#'
        b'\xae\xb0\xaa9\xa6*8hV\xd1\xec]\x1ch\xc0q\xf4*\xda\xc7G\xf1Tk\x8e\x17\x16\xce6]X&\x86\xb2U\x1d\xd2\x9d1\x95\x07\xdf\x01\xeerM\x0b\xf1\xba\xe6\x19\xd0\x01\xab\xb6\xff\xc7\xa5\x19X5gow'
        b'\xf4\x14\xc2\xcf\xaa\x14?>8\xee\x00o\xeb)\x8f\x94\xea\x9bmL\xfd\xf5s\x87(\xa7\xf6\xb0]W3\x91\xf5c\x8f\t\xef<\xb1\xb9\x02\xcd\x1aI\x91\x98v\xe9\x00\xc8\n4\xbf\xc6\xb5I\xbf\xb6<6\x18\xe3B\x93'
        b"\x8a\x15\xcfl;^f\xf9}\x18\x01`C\xac\x1aw\x86\xca\xc3\x89\x10\x87\xe3\x1c@q\x11<'c\xee\xbe\x8e\x16-\xf4^\x98\xf1\xe2\xc2\xd9uu\xf3\x19\x91{\xb06)T\xda\xde\xd8\xc9<spf\xa6\xdd@\x80"
        b'\x18\x8d!\xba\xe9\x83w\x1a\x8aI\x7fWJ)\x1f\x0f\xe5\x9eN\xa1h\x98-l\xe4\xb7\x06Z\x08\xda\xfc\xd8\xb3\xe0:\xd5x\xf1\xc6\xe0\xa5S\xe3Z6lt\xf7\xb9\xcfN\x18\x9f-\xacn\xd1o\xca\xc4\xc4\x96\xfe+'
        b'\xc6\xb7Fs\x07\xf8\xd1zo,\x8b\xffCj\xbb\x90a\xe8\xc9[\xe4-\xce\x19\xc7\xa8\x8d:"P\xb1p*\x80\xfc\xf7W_c(\x8a\x94\x8d\x81\x82\x8a\x9f\x91s\xba\xc8h\xb5]\xcd\x1c\xa8\xb0\x95t\x88\x7f\x99s'
        b'XI3\x0f\n\xa7(g&\xc4c\xeb\xab,\xda\xf5\x98\x15\xc6\x19V\xf4j\xb1\x07/fFw\xd1\xab2pM\xe4[\x8d"\xba5\xb4F\x15_\xd6R\xeb\x00#\x7f\x9d<\r\xa57\xb3\xbc#\x9d$|i,\xf3'
        b'&,\x8f\xfe\xd3\xc5\x14\x9fi\xaf\r\xb5\xbbB\xadv"\xa6\xd52\x93\xfb\xff/\x97\x90tKT\x94/\xca\\\xdaM\xdb\x1d\xbb\xe0\xcc\x8c\x04e\x96\x12%\xf2\x9a\x1c\x84\xfb\x8f\x7fv0\xdd\xd7\xf6\x15\xb6A\xea\xcc\x89'
        b'\x9cEzR\xdbN\x04\x84b\x15\xdf\xdb+S\x83kX4\xfe\xd5\x0c3\xea\xbf\xbc\x00\r.e\xd8\xe8SKb\xdav\xe2Kbj\x97W\xfa\xce\xb8i\x8d\x17f3\xd5\xcaX\x9b\x9d\x80%\xd2"\xb9\x12\xb8\x1by'
        b'\xb6\xb8\xba\x06\xbc)T\xf2\x18}Q\xa0;\x19\x18\xa31\xb6\xe6kK\xcc\xdd\x02u\xeb\x98\xc8i\xb2\xe4\xdf\xbd\xa9\x01\x97S\x11JJ\x91\x0cH\x99J\x99/vJ.\xf9J\x94\xbc\x04\x87S\x89A\x0c;+o\xc8'
        b'\x10\xc0\xd14\x0fY(\xf6]x\xf0FB\xbe\x80\x8cFC\xd9xT\xe5$\xbc\x8e\x18\xcf\xbb\x17\xcb\xe4C7\rr\xf0\xe19\xdf0:)s\x15\xaf\x10c\x9b\xbb\xcb0\xdb\x037\xfd\xcco\x10f\x1f\x0fn?\xce'
        b'nR\xf69\x99uR\x939\xa5\x86\xd9qC\xd8p\x92\xf0\xbdM\xaa\x93\xa9\xbf>7\x0e\xb0\x1a\x8e[\x03#\xfe02\x8b\xcc\xe8\xd0]\xc3Y[\xd6nvu\x0f\x911\xb7f\xdb\x03p\x8a19\x99\xac\x91\xe4\xed'
        b'\xb3q\xb7\x17\xf4\xa0\x1cp\xc2d\x9a\xd1r\xb5\xf8F\xfd\xebC=\x9f\xb3\\O\x1e\xf9\x9b\x99@\xabeP\x87$\x0e\xdb\x08\xec\xe6Q\x865l\xbf\xb5\xfc#:\xb4\xf3R\xc3\xf5J\x10\xf7\\F@e[\x84\x02\x12'
        b'\x15\x1d^\xcci\x1d<R\x1d\n\x82\xad{\xb7v\x81\x8f,\xf1|\xb4\x01`\x05\xe9;\x80\xf5\xfa=v]\xbfs\x9bC7\x0b\x07\xf4z\x81(R^\xe4\xc1\x9a\xc82\xfb\xc1\x00\xde\xf29\r\x0f0es\xfe\xe53'
        b'\x1e\xefX\x04\xbe\x9fM\xd1\x0c\xea\xd5qU\x95\x98\x1d]`\xa3\xfc\x1c\xaes\xc7V\x84\xd8\xdc&m\xc7\xf84\x03\xca\xec\x0c\x9a\xbf\xd7\xf2a\x90_^j\xec\x93`\xb3X\x01r\x16$n\xd0^\xa0C:\x95 \xac'
        b"C(\xce'\xa7\xa5\xd66\x8a\xc9CE\xaa\x06\xc2\xb2v\x8c\xc1\x06Dc\xff\x95T\t\x11N2\xa7\xb6j\xa2\xd8k\xd4r2\xfe\x03\xeeR\x8b2\x0b\x8e\xbe\xde\xfa]\xbd\xb4\xb6\xe25F\xf5M\xb3\xb6~W\x08\x1e"
        b'k#\xba\xdf\x1a\xe5d\x11\xbe\xea\xb50\xbcf\xdf\x15\xd1\\\x0c\xed\t&<\x8a\x88\xb3\xb1+\xba\xad:R\xee\xc1\x19F6\xc9O\x97I\xc4\xce\xca\xa6(\xca~^\xe1uYE\xd6c[\x8a\xd7\x00\x88\xdf\xbd\xe3a'
        b'\xef\t\x9e\xed\xdcy3/W\xa6\\\xfb\xff\xde\xde\x84\xdf5<\xc2J\x93\xfd\x1cC\x06\x12\x8ebV\x1e[0\xb4E\x11\x9bI\xc8\x98x\x996\x9a\xb3\xe9\xde\xb2\xbb\x88H\xff\x00K\xf0\xa1]\xf8\xcf\xea\x1b\xe8|R'
        b'\xe8\x00\x05`1\x1f|4T\xb5\xd0\xa9\xbe\xdbH\xf7bv\xc5\\\xfaw\xba\x07M\xedF\xd3\xfae\xa5\\\x19\x1d*53P\xee\xd7\x14\x05\xe9T\xf5\xd8M\x8c\x1c?g^\xaa\xedS\xc6\x04\x9eg\xe2\r\xbcY\xa8'
        b'Ir\xa3\x9b,B[\x9a\xc5\xde\x19\xe1\xb3Q\xc7\xa3\xf2\xa5\xae\x80\xf5\xd8\x84\xeb\x19\xe6\xfc\x86\x9b\xbb`\x1d\x07\xc8\xfcy\xa4\xbd\x0bV\xb6B0\xd5{)\x89U\xcbf\xc6\xb8\xcb\xa0\x9d\rB%\xb9\xcd\x81\x7f\x11\x83'
        b'lM\xd1 Pw<\x02\x13\x12w\x0c\xa7\x14\xfe1\xban7\x15s\x19\xb6`\x1dj@\xe80\xd0\x01\x94\xbbBJ\x01\xcd\x9e\xed\xda\xc4:\x11\xac{6\x9frL\xb7\xb8&\x15\xc0\xb0\xa7\x87\xa8\x16\xb0\x8b+\xa9-'
        b"s\xc1\xfc\xea\xb2h\x00X\x07\x9d\xf6$l\xf0\xa4\xabV\x18\x16\xeb*\xfcC][\xf8\x9c\xc2g\xc4R\xac\x91P\\\x988\x08\x98\xc9\xc5\xb1\x90\\\x1fH4?\xdd\xac\xac'\xc20\x9f\xb2{\x1e\xad\xf1.\x97s\n"
        b'\xf9\xe6\x9a$\x9c\xc6\xab\xd2X\xdf\xa0\xfd,\xcc\xfa\x1c\xfb\xbd\x87"\x16\xb3})|3%\x00\x1cq\\.\x1dfg_\x98-F\xce\\\xe2gC\xbcEO\xfe\xc6*\\\x8f\xf22P$iVnms\xde\xf2\x9f'
        b'I\xc8a\xa2\x12TX)\x85g\xb7\x9a]1\x1a3\xfe,\xdd\xd7\xa5\xe2\xd3\\z\xf1\xd7\x89\x1b\xbac\xbf\xf7\x00\xebL\xf7\xb4\xb9\xff\x18\r:\x06Q\x15\xafx"\x05\xa3\x96\x8d\x82\x01P\xf2\r}\xc5mxT\x1f'
        b"+\xf9\xc3\xae0$\xd3\x98\x00$\xf3\xe7\x86\n\x12\xb0vL\xee'\xb7\xbb\xad\r\xc3\xdd?\xad\xae\xc4\xf2h\xff\xc5CC\n\xbe\x19\x9e\x94\xad\xe4huc\x0e\x8c\xad\x0e\xf0$Bx\xc6\x11\xa4Y+\x06\xb5\xa7\xbf\xb6"
        b'\xa1?\x08\xae\xa2\xa6j\r\xdcjxur\x07&#|}\x15\xccSK\xe1!e\x03\xf1{g\xa1\xaai}\x8de\xbe+\x10\xbc\x15\xdbk\xb4\x02\xc7\x18\x89:\x97V\xd8\x8f\x94l\xa2P\xe2\xab)8\xe2\xdet#'
        b'\x89n@\xbc\xd4\xa5W)I\xd6\xb5L\xf2\xba\x08\x85\xa78\xac\x80\x11\x9a\n:\x08\x83\x98\xado\xcf)x\xd4\x1c\xcd\xb8\xfa\x1f\xeb\x9a7\xc8\xc5\xc9\xd7f\xe7\x04\xd2)R\x84x\xa1\xf3\x97*S\x08\xcfE\xbc\x1b\xc2'
        b'\x87\xe56\xd6\x11R#\xca\xeeh\x90\x08\x82%\xc2\x9eI\xca\xc0c\x88\x97\xfc\x7f\x973\x952\x99\x15\x89oP\x01\xb3\x12\x92,Lm\xc1\xf4\x90?\x12\x87\xc7)wG\xa4\x01(\x03\x14\xde\xcb\x8fi9\x89N\xe8\x0c'
        b'\x81\xbc\x95\x1cq@d\x97\x17\xd51\x1fl\xdc\xe1D\x11\x06\xf4\x04|x\x0e\xe5\x17\xa2\x84\x07\x03\x1c?\x9f\x0c\xc2\x15\xe2\x9c\x84I\xda\x86\x1eE\xe9\x06VL\xbe\xee\xbbRc\xfc\x9801\xb3\xc3!\xe6bP\xe8\xf1'
        b'd\x02m\x88OXm\x15\xbf\xd9\xd1\xc85\xa4\xbf\x04!\xcd3\x92\x1c\n3N\xb3\xc4\xdaS\x8bzqXuI\x17$\xbaq\x7f\xd0\xa6\x8c0\x01\x1e\x1f|\xefVmg,\x08`\xc4Z\x04\xf48\x1b\xc1\x07\xa0\xd2'
        b'\xd2\xda/E\x89}j\x87U\xf2!QQ2\xed\x0c\x94\xd4\xf2\x13\x04h\x8bv\x11\xd2~\xa9ns\x0c\x11\x07\x10\x81W\x08v\xd9n\xfe\xcc\xd3\xfd\xf2\x12\xdf\xe7\xbb\xf8\xa6\xd5\xea\x1d\xdf\xeb\xfd\x8f\x17\x1b(\x13\xabk'
        b'\x9f(\x1cs\xc8\x01%\x07HT=\x82\xf9 \xdc\x0b\x8f\n\xd7^\x98[\xf2\xa2X\x85-\x88\xd2\xeb\xbb\xf35\xba\xaf^in:\xf0\xc7\x843$\xecf\x90\xa6_\xf2\xe9\x01\x00\x00\x00N)\x04Z\x0b__py'
        b'armor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen f'
        b'intech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
